<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance.bill');

// 记录访问日志
record_log('访问电子账单页面');

// 处理导出操作
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'export') {
    $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
    $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
    $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
    $trans_type = isset($_POST['trans_type']) ? intval($_POST['trans_type']) : 0;

    try {
        // 构建查询条件
        $where = [];
        $params = [];

        if (!empty($start_date)) {
            $where[] = "t.trans_date >= ?";
            $params[] = $start_date;
        }

        if (!empty($end_date)) {
            $where[] = "t.trans_date <= ?";
            $params[] = $end_date;
        }

        if ($store_id > 0) {
            $where[] = "t.store_id = ?";
            $params[] = $store_id;
        }

        if ($trans_type > 0) {
            $where[] = "t.trans_type = ?";
            $params[] = $trans_type;
        }

        // 构建查询SQL
        $sql = "
            SELECT 
                t.id, 
                s.store_name, 
                t.trans_type, 
                t.amount, 
                t.trans_date, 
                t.related_id, 
                t.description, 
                t.operator, 
                t.create_time
            FROM fin_transaction t
            LEFT JOIN store_info s ON t.store_id = s.id
        ";

        if (!empty($where)) {
            $sql .= " WHERE " . implode(' AND ', $where);
        }

        $sql .= " ORDER BY t.trans_date DESC, t.id DESC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $transactions = $stmt->fetchAll();

        // 生成CSV文件
        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename="账单导出_' . date('YmdHis') . '.csv"');

        $output = fopen('php://output', 'w');

        // 输出BOM头，以便Excel正确显示中文
        fprintf($output, chr(0xEF) . chr(0xBB) . chr(0xBF));

        // 输出CSV标题行
        fputcsv($output, ['交易ID', '门店', '交易类型', '金额', '交易日期', '关联ID', '交易描述', '操作人', '创建时间']);

        // 输出数据行
        foreach ($transactions as $row) {
            // 格式化交易类型
            $type_str = '';
            switch ($row['trans_type']) {
                case 1:
                    $type_str = '销售收入';
                    break;
                case 2:
                    $type_str = '进货支出';
                    break;
                case 3:
                    $type_str = '工资支出';
                    break;
                case 4:
                    $type_str = '设备维护支出';
                    break;
                case 5:
                    $type_str = '其他收入';
                    break;
                case 6:
                    $type_str = '其他支出';
                    break;
                default:
                    $type_str = '未知类型';
            }

            fputcsv($output, [
                $row['id'],
                $row['store_name'],
                $type_str,
                $row['amount'],
                $row['trans_date'],
                $row['related_id'] ?: '',
                $row['description'] ?: '',
                $row['operator'] ?: '',
                $row['create_time']
            ]);
        }

        fclose($output);
        exit;
    } catch (PDOException $e) {
        $error = '导出账单失败：' . $e->getMessage();
    }
}

// 筛选条件
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';
$filter_trans_type = isset($_GET['trans_type']) ? intval($_GET['trans_type']) : 0;
$filter_operator = isset($_GET['operator']) ? trim($_GET['operator']) : '';
$filter_description = isset($_GET['description']) ? trim($_GET['description']) : '';

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "t.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_trans_type > 0) {
    $where[] = "t.trans_type = ?";
    $params[] = $filter_trans_type;
}

if (!empty($filter_start_date)) {
    $where[] = "t.trans_date >= ?";
    $params[] = $filter_start_date;
}

if (!empty($filter_end_date)) {
    $where[] = "t.trans_date <= ?";
    $params[] = $filter_end_date;
}

if (!empty($filter_operator)) {
    $where[] = "t.operator LIKE ?";
    $params[] = "%{$filter_operator}%";
}

if (!empty($filter_description)) {
    $where[] = "t.description LIKE ?";
    $params[] = "%{$filter_description}%";
}

// 分页参数
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$page_size = 20; // 每页显示20条
$offset = ($page - 1) * $page_size;

// 获取交易记录总数
try {
    $count_sql = "SELECT COUNT(*) as count FROM fin_transaction t";

    if (!empty($where)) {
        $count_sql .= " WHERE " . implode(' AND ', $where);
    }

    $stmt = $pdo->prepare($count_sql);
    $stmt->execute($params);
    $count_result = $stmt->fetch();
    $total_records = $count_result['count'];
    $total_pages = ceil($total_records / $page_size);
} catch (PDOException $e) {
    $error = '获取交易记录数量失败：' . $e->getMessage();
    $total_records = 0;
    $total_pages = 0;
}

// 获取交易记录数据
try {
    $sql = "
        SELECT 
            t.id, 
            s.store_name, 
            t.trans_type, 
            t.amount, 
            t.trans_date, 
            t.related_id, 
            t.description, 
            t.operator, 
            t.create_time
        FROM fin_transaction t
        LEFT JOIN store_info s ON t.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    // 直接在SQL语句中嵌入LIMIT参数
    $sql .= " ORDER BY t.trans_date DESC, t.id DESC LIMIT " . (int)$offset . ", " . (int)$page_size;

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params); // 只传递WHERE条件的参数
    $transactions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取交易记录失败：' . $e->getMessage();
    $transactions = [];
}

// 获取交易统计数据
try {
    $stats_sql = "
        SELECT 
            SUM(CASE WHEN trans_type IN (1, 5) THEN amount ELSE 0 END) as total_income,
            SUM(CASE WHEN trans_type IN (2, 3, 4, 6) THEN amount ELSE 0 END) as total_expense,
            COUNT(*) as total_transactions
        FROM fin_transaction t
    ";

    if (!empty($where)) {
        $stats_sql .= " WHERE " . implode(' AND ', $where);
    }

    $stmt = $pdo->prepare($stats_sql);
    $stmt->execute($params);
    $stats = $stmt->fetch();

    $total_income = $stats['total_income'] ?: 0;
    $total_expense = $stats['total_expense'] ?: 0;
    $net_balance = $total_income - $total_expense;
} catch (PDOException $e) {
    $error = '获取交易统计数据失败：' . $e->getMessage();
    $total_income = 0;
    $total_expense = 0;
    $net_balance = 0;
}

// 页面标题
$page_title = "电子账单";
if (!empty($filter_start_date) && !empty($filter_end_date)) {
    $page_title .= " ({$filter_start_date} 至 {$filter_end_date})";
} else {
    $page_title .= " (全部数据)";
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2><?php echo $page_title; ?></h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 电子账单
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="trans_type">交易类型：</label>
                            <select id="trans_type" name="trans_type">
                                <option value="0">全部类型</option>
                                <option value="1" <?php echo ($filter_trans_type == 1) ? 'selected' : ''; ?>>销售收入</option>
                                <option value="2" <?php echo ($filter_trans_type == 2) ? 'selected' : ''; ?>>进货支出</option>
                                <option value="3" <?php echo ($filter_trans_type == 3) ? 'selected' : ''; ?>>工资支出</option>
                                <option value="4" <?php echo ($filter_trans_type == 4) ? 'selected' : ''; ?>>设备维护支出</option>
                                <option value="5" <?php echo ($filter_trans_type == 5) ? 'selected' : ''; ?>>其他收入</option>
                                <option value="6" <?php echo ($filter_trans_type == 6) ? 'selected' : ''; ?>>其他支出</option>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="operator">操作人：</label>
                            <input type="text" id="operator" name="operator" value="<?php echo htmlspecialchars($filter_operator); ?>" placeholder="输入操作人姓名">
                        </div>

                        <div class="filter-item">
                            <label for="description">描述关键词：</label>
                            <input type="text" id="description" name="description" value="<?php echo htmlspecialchars($filter_description); ?>" placeholder="输入交易描述关键词">
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="bill.php" class="btn btn-secondary">重置</a>
                            <button type="submit" name="action" value="export" class="btn btn-success" formmethod="post">导出账单</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 统计摘要 -->
            <div class="info-box">
                <h3>账单统计摘要<?php echo (!empty($filter_start_date) && !empty($filter_end_date)) ? " ({$filter_start_date} 至 {$filter_end_date})" : " (全部数据)"; ?></h3>
                <ul>
                    <li>总收入：￥<?php echo number_format($total_income, 2); ?></li>
                    <li>总支出：￥<?php echo number_format($total_expense, 2); ?></li>
                    <li>净收支：￥<?php echo number_format($net_balance, 2); ?> <span style="color: <?php echo $net_balance >= 0 ? 'green' : 'red'; ?>;">(<?php echo $net_balance >= 0 ? '盈余' : '亏损'; ?>)</span></li>
                    <li>交易记录数：<?php echo number_format($stats['total_transactions']); ?> 条</li>
                </ul>
            </div>

            <!-- 交易记录列表 -->
            <div class="table-container">
                <h3>交易记录列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>门店</th>
                            <th>交易类型</th>
                            <th>金额</th>
                            <th>交易日期</th>
                            <th>交易描述</th>
                            <th>关联ID</th>
                            <th>操作人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($transactions)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无交易记录数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($transactions as $transaction): ?>
                                <tr>
                                    <td><?php echo $transaction['id']; ?></td>
                                    <td><?php echo htmlspecialchars($transaction['store_name']); ?></td>
                                    <td>
                                        <?php
                                        $type_class = '';
                                        if ($transaction['trans_type'] == 1 || $transaction['trans_type'] == 5) {
                                            $type_class = 'status-active';
                                        } else {
                                            $type_class = 'status-inactive';
                                        }

                                        switch ($transaction['trans_type']) {
                                            case 1:
                                                echo "<span class=\"{$type_class}\">销售收入</span>";
                                                break;
                                            case 2:
                                                echo "<span class=\"{$type_class}\">进货支出</span>";
                                                break;
                                            case 3:
                                                echo "<span class=\"{$type_class}\">工资支出</span>";
                                                break;
                                            case 4:
                                                echo "<span class=\"{$type_class}\">设备维护支出</span>";
                                                break;
                                            case 5:
                                                echo "<span class=\"{$type_class}\">其他收入</span>";
                                                break;
                                            case 6:
                                                echo "<span class=\"{$type_class}\">其他支出</span>";
                                                break;
                                            default:
                                                echo "未知类型";
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo number_format($transaction['amount'], 2); ?></td>
                                    <td><?php echo $transaction['trans_date']; ?></td>
                                    <td><?php echo htmlspecialchars($transaction['description'] ?: '-'); ?></td>
                                    <td>
                                        <?php if ($transaction['related_id']): ?>
                                            <?php
                                            // 根据交易类型显示不同的文本
                                            $display_text = $transaction['related_id'];

                                            switch ($transaction['trans_type']) {
                                                case 1: // 销售收入
                                                    $display_text = "订单#" . $transaction['related_id'];
                                                    break;
                                                case 2: // 进货支出
                                                    $display_text = "采购#" . $transaction['related_id'];
                                                    break;
                                                case 3: // 工资支出
                                                    $display_text = "工资#" . $transaction['related_id'];
                                                    break;
                                                case 4: // 设备维护支出
                                                    $display_text = "维护#" . $transaction['related_id'];
                                                    break;
                                            }
                                            ?>
                                            <?php echo $display_text; ?>
                                        <?php else: ?>
                                            -
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($transaction['operator'] ?: '-'); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($transaction['create_time'])); ?></td>
                                    <td>
                                        <a href="income.php?action=edit&id=<?php echo $transaction['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <?php if ($transaction['trans_type'] == 5 || $transaction['trans_type'] == 6): ?>
                                            <a href="income.php?action=edit&id=<?php echo $transaction['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页控件 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1&store_id=<?php echo $filter_store_id; ?>&trans_type=<?php echo $filter_trans_type; ?>&start_date=<?php echo $filter_start_date; ?>&end_date=<?php echo $filter_end_date; ?>&operator=<?php echo urlencode($filter_operator); ?>&description=<?php echo urlencode($filter_description); ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo ($page - 1); ?>&store_id=<?php echo $filter_store_id; ?>&trans_type=<?php echo $filter_trans_type; ?>&start_date=<?php echo $filter_start_date; ?>&end_date=<?php echo $filter_end_date; ?>&operator=<?php echo urlencode($filter_operator); ?>&description=<?php echo urlencode($filter_description); ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    // 显示页码链接
                    $start_page = max(1, $page - 2);
                    $end_page = min($total_pages, $page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++) {
                        echo '<a href="?page=' . $i . '&store_id=' . $filter_store_id . '&trans_type=' . $filter_trans_type . '&start_date=' . $filter_start_date . '&end_date=' . $filter_end_date . '&operator=' . urlencode($filter_operator) . '&description=' . urlencode($filter_description) . '" class="page-link">' . $i . '</a>';
                    }
                    ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo ($page + 1); ?>&store_id=<?php echo $filter_store_id; ?>&trans_type=<?php echo $filter_trans_type; ?>&start_date=<?php echo $filter_start_date; ?>&end_date=<?php echo $filter_end_date; ?>&operator=<?php echo urlencode($filter_operator); ?>&description=<?php echo urlencode($filter_description); ?>" class="page-link">下一页</a>
                        <a href="?page=' . $total_pages . '&store_id=' . $filter_store_id . '&trans_type=' . $filter_trans_type . '&start_date=' . $filter_start_date . '&end_date=' . $filter_end_date . '&operator=' . urlencode($filter_operator) . '&description=' . urlencode($filter_description) . '" class="page-link">尾页</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>