<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance.profit');

// 记录访问日志
record_log('访问利润分析页面');

// 添加/编辑利润分析记录处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加利润分析记录
    if ($_POST['action'] == 'add') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $period = isset($_POST['period']) ? trim($_POST['period']) : '';
        $total_revenue = isset($_POST['total_revenue']) ? floatval($_POST['total_revenue']) : 0;
        $material_cost = isset($_POST['material_cost']) ? floatval($_POST['material_cost']) : 0;
        $labor_cost = isset($_POST['labor_cost']) ? floatval($_POST['labor_cost']) : 0;
        $other_cost = isset($_POST['other_cost']) ? floatval($_POST['other_cost']) : 0;

        // 计算总成本、毛利润和毛利率
        $total_cost = $material_cost + $labor_cost + $other_cost;
        $gross_profit = $total_revenue - $total_cost;
        $gross_profit_rate = ($total_revenue > 0) ? round(($gross_profit / $total_revenue) * 100, 2) : 0;
        $net_profit = $gross_profit; // 简化模型，净利润等于毛利润

        if ($store_id <= 0 || empty($period) || $total_revenue < 0) {
            $error = '请填写完整利润分析信息！';
        } else {
            try {
                // 检查同一门店同一周期是否已存在记录
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_profit WHERE store_id = ? AND period = ?");
                $stmt->execute([$store_id, $period]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该门店的利润分析周期已存在！';
                } else {
                    // 添加利润分析记录
                    $stmt = $pdo->prepare("INSERT INTO fin_profit (store_id, period, total_revenue, total_cost, material_cost, labor_cost, other_cost, gross_profit, gross_profit_rate, net_profit) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$store_id, $period, $total_revenue, $total_cost, $material_cost, $labor_cost, $other_cost, $gross_profit, $gross_profit_rate, $net_profit]);

                    if ($result) {
                        record_log("添加利润分析记录：{$period} - 门店ID:{$store_id}");
                        $success = '利润分析记录添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: profit.php?success=add');
                        exit;
                    } else {
                        $error = '利润分析记录添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑利润分析记录
    elseif ($_POST['action'] == 'edit') {
        $profit_id = isset($_POST['profit_id']) ? intval($_POST['profit_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $period = isset($_POST['period']) ? trim($_POST['period']) : '';
        $total_revenue = isset($_POST['total_revenue']) ? floatval($_POST['total_revenue']) : 0;
        $material_cost = isset($_POST['material_cost']) ? floatval($_POST['material_cost']) : 0;
        $labor_cost = isset($_POST['labor_cost']) ? floatval($_POST['labor_cost']) : 0;
        $other_cost = isset($_POST['other_cost']) ? floatval($_POST['other_cost']) : 0;

        // 计算总成本、毛利润和毛利率
        $total_cost = $material_cost + $labor_cost + $other_cost;
        $gross_profit = $total_revenue - $total_cost;
        $gross_profit_rate = ($total_revenue > 0) ? round(($gross_profit / $total_revenue) * 100, 2) : 0;
        $net_profit = $gross_profit; // 简化模型，净利润等于毛利润

        if ($profit_id <= 0 || $store_id <= 0 || empty($period) || $total_revenue < 0) {
            $error = '请填写完整利润分析信息！';
        } else {
            try {
                // 检查同一门店同一周期是否已存在记录（排除当前记录）
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_profit WHERE store_id = ? AND period = ? AND id != ?");
                $stmt->execute([$store_id, $period, $profit_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该门店的利润分析周期已存在！';
                } else {
                    // 更新利润分析记录
                    $stmt = $pdo->prepare("UPDATE fin_profit SET store_id = ?, period = ?, total_revenue = ?, total_cost = ?, material_cost = ?, labor_cost = ?, other_cost = ?, gross_profit = ?, gross_profit_rate = ?, net_profit = ? WHERE id = ?");
                    $result = $stmt->execute([$store_id, $period, $total_revenue, $total_cost, $material_cost, $labor_cost, $other_cost, $gross_profit, $gross_profit_rate, $net_profit, $profit_id]);

                    if ($result) {
                        record_log("编辑利润分析记录：{$period} - 门店ID:{$store_id}");
                        $success = '利润分析记录更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: profit.php?success=edit');
                        exit;
                    } else {
                        $error = '利润分析记录更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除利润分析记录
    elseif ($_POST['action'] == 'delete') {
        $profit_id = isset($_POST['profit_id']) ? intval($_POST['profit_id']) : 0;

        if ($profit_id <= 0) {
            $error = '无效的利润分析记录ID！';
        } else {
            try {
                // 获取利润分析记录信息，用于日志记录
                $stmt = $pdo->prepare("SELECT period, store_id FROM fin_profit WHERE id = ?");
                $stmt->execute([$profit_id]);
                $profit = $stmt->fetch();

                if (!$profit) {
                    $error = '利润分析记录不存在！';
                } else {
                    // 删除利润分析记录
                    $stmt = $pdo->prepare("DELETE FROM fin_profit WHERE id = ?");
                    $result = $stmt->execute([$profit_id]);

                    if ($result) {
                        record_log("删除利润分析记录：{$profit['period']} - 门店ID:{$profit['store_id']}");
                        $success = '利润分析记录删除成功！';
                    } else {
                        $error = '利润分析记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_year = isset($_GET['year']) ? trim($_GET['year']) : '';
$filter_period_type = isset($_GET['period_type']) ? trim($_GET['period_type']) : 'month'; // month 或 quarter

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "p.store_id = ?";
    $params[] = $filter_store_id;
}

if (!empty($filter_year)) {
    if ($filter_period_type == 'month') {
        $where[] = "p.period LIKE ?";
        $params[] = $filter_year . '-%';
    } else { // quarter
        $where[] = "(p.period = ? OR p.period = ? OR p.period = ? OR p.period = ?)";
        $params[] = $filter_year . '-Q1';
        $params[] = $filter_year . '-Q2';
        $params[] = $filter_year . '-Q3';
        $params[] = $filter_year . '-Q4';
    }
}

// 获取利润分析数据
try {
    $sql = "
        SELECT p.*, s.store_name 
        FROM fin_profit p
        LEFT JOIN store_info s ON p.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY p.period DESC, p.store_id";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $profits = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取利润分析记录失败：' . $e->getMessage();
    $profits = [];
}

// 计算材料成本占比
foreach ($profits as &$profit) {
    $profit['material_cost_ratio'] = ($profit['total_revenue'] > 0) ? round(($profit['material_cost'] / $profit['total_revenue']) * 100, 2) : 0;
}

// 判断是否显示表单
$show_form = false;
$edit_profit = null;

// 编辑利润分析记录时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM fin_profit WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_profit = $stmt->fetch();
        if (!$edit_profit) {
            $error = '利润分析记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取利润分析记录信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加利润分析记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '利润分析记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '利润分析记录更新成功！';
    }
}

// 获取可选的年份列表（从最早的记录年份到当前年份）
try {
    $stmt = $pdo->query("SELECT MIN(period) as min_period FROM fin_profit");
    $result = $stmt->fetch();
    $min_year = (!empty($result['min_period'])) ? intval(substr($result['min_period'], 0, 4)) : date('Y');
    $current_year = date('Y');
    $years = range($current_year, $min_year);
} catch (PDOException $e) {
    $years = [date('Y')];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>利润分析</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 利润分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="profit.php?action=add" class="btn btn-add">添加利润分析记录</a>
            </div>

            <!-- 添加/编辑利润分析记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_profit ? '编辑利润分析记录' : '添加利润分析记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_profit ? 'edit' : 'add'; ?>">
                        <?php if ($edit_profit): ?>
                            <input type="hidden" name="profit_id" value="<?php echo $edit_profit['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">选择门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">请选择门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($edit_profit && $edit_profit['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="period">统计周期：</label>
                            <input type="text" id="period" name="period" value="<?php echo $edit_profit ? htmlspecialchars($edit_profit['period']) : ''; ?>" required placeholder="格式：YYYY-MM 或 YYYY-Q1">
                            <small>例如：2023-05（表示2023年5月）或 2023-Q2（表示2023年第二季度）</small>
                        </div>

                        <div class="form-group">
                            <label for="total_revenue">总收入：</label>
                            <input type="number" id="total_revenue" name="total_revenue" step="0.01" min="0" value="<?php echo $edit_profit ? htmlspecialchars($edit_profit['total_revenue']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="material_cost">原料成本：</label>
                            <input type="number" id="material_cost" name="material_cost" step="0.01" min="0" value="<?php echo $edit_profit ? htmlspecialchars($edit_profit['material_cost']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="labor_cost">人工成本：</label>
                            <input type="number" id="labor_cost" name="labor_cost" step="0.01" min="0" value="<?php echo $edit_profit ? htmlspecialchars($edit_profit['labor_cost']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="other_cost">其他成本：</label>
                            <input type="number" id="other_cost" name="other_cost" step="0.01" min="0" value="<?php echo $edit_profit ? htmlspecialchars($edit_profit['other_cost']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="profit.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">门店：</label>
                                <select id="store_id" name="store_id">
                                    <option value="0">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="year">年份：</label>
                                <select id="year" name="year">
                                    <option value="" <?php echo ($filter_year == '') ? 'selected' : ''; ?>>全部年份</option>
                                    <?php foreach ($years as $year): ?>
                                        <option value="<?php echo $year; ?>" <?php echo ($filter_year == $year) ? 'selected' : ''; ?>>
                                            <?php echo $year; ?>年
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="period_type">周期类型：</label>
                                <select id="period_type" name="period_type">
                                    <option value="month" <?php echo ($filter_period_type == 'month') ? 'selected' : ''; ?>>月度</option>
                                    <option value="quarter" <?php echo ($filter_period_type == 'quarter') ? 'selected' : ''; ?>>季度</option>
                                </select>
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="profit.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计摘要 -->
                <?php
                $total_revenue_sum = 0;
                $total_cost_sum = 0;
                $material_cost_sum = 0;
                $labor_cost_sum = 0;
                $other_cost_sum = 0;
                $net_profit_sum = 0;

                foreach ($profits as $profit) {
                    $total_revenue_sum += $profit['total_revenue'];
                    $total_cost_sum += $profit['total_cost'];
                    $material_cost_sum += $profit['material_cost'];
                    $labor_cost_sum += $profit['labor_cost'];
                    $other_cost_sum += $profit['other_cost'];
                    $net_profit_sum += $profit['net_profit'];
                }

                $avg_gross_profit_rate = ($total_revenue_sum > 0) ? round(($net_profit_sum / $total_revenue_sum) * 100, 2) : 0;
                $avg_material_cost_ratio = ($total_revenue_sum > 0) ? round(($material_cost_sum / $total_revenue_sum) * 100, 2) : 0;
                ?>

                <div class="info-box">
                    <h3>统计摘要（<?php echo empty($filter_year) ? '全部年份' : $filter_year . '年'; ?><?php echo $filter_period_type == 'month' ? '月度' : '季度'; ?>数据）</h3>
                    <ul>
                        <li>总收入：￥<?php echo number_format($total_revenue_sum, 2); ?></li>
                        <li>总成本：￥<?php echo number_format($total_cost_sum, 2); ?></li>
                        <li>净利润：￥<?php echo number_format($net_profit_sum, 2); ?></li>
                        <li>平均毛利率：<?php echo $avg_gross_profit_rate; ?>%</li>
                        <li>原料成本占比：<?php echo $avg_material_cost_ratio; ?>%</li>
                    </ul>
                </div>

                <!-- 利润分析记录列表 -->
                <div class="table-container">
                    <h3>利润分析列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店</th>
                                <th>统计周期</th>
                                <th>总收入</th>
                                <th>总成本</th>
                                <th>原料成本</th>
                                <th>原料成本占比</th>
                                <th>人工成本</th>
                                <th>其他成本</th>
                                <th>毛利润</th>
                                <th>毛利率</th>
                                <th>净利润</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($profits)): ?>
                                <tr>
                                    <td colspan="13" class="text-center">暂无利润分析数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($profits as $profit): ?>
                                    <tr>
                                        <td><?php echo $profit['id']; ?></td>
                                        <td><?php echo htmlspecialchars($profit['store_name']); ?></td>
                                        <td><?php echo htmlspecialchars($profit['period']); ?></td>
                                        <td>￥<?php echo number_format($profit['total_revenue'], 2); ?></td>
                                        <td>￥<?php echo number_format($profit['total_cost'], 2); ?></td>
                                        <td>￥<?php echo number_format($profit['material_cost'], 2); ?></td>
                                        <td><?php echo $profit['material_cost_ratio']; ?>%</td>
                                        <td>￥<?php echo number_format($profit['labor_cost'], 2); ?></td>
                                        <td>￥<?php echo number_format($profit['other_cost'], 2); ?></td>
                                        <td>￥<?php echo number_format($profit['gross_profit'], 2); ?></td>
                                        <td><?php echo $profit['gross_profit_rate']; ?>%</td>
                                        <td>￥<?php echo number_format($profit['net_profit'], 2); ?></td>
                                        <td>
                                            <a href="profit.php?action=edit&id=<?php echo $profit['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="profit_id" value="<?php echo $profit['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该利润分析记录吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>