<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order.category');

// 记录访问日志
record_log('访问订单分类管理页面');

// 获取统计时间范围
$has_date_filter = isset($_GET['start_date']) && isset($_GET['end_date']) && !empty($_GET['start_date']) && !empty($_GET['end_date']);
$start_date = $has_date_filter ? $_GET['start_date'] : '';
$end_date = $has_date_filter ? $_GET['end_date'] : '';

// 订单类型定义
$order_types = [
    1 => ['name' => '堂食', 'description' => '顾客在店内就餐的订单'],
    2 => ['name' => '外带', 'description' => '顾客到店自取带走的订单'],
    3 => ['name' => '外卖', 'description' => '通过外卖平台或电话下单配送的订单']
];

// 订单来源定义
$order_sources = [
    1 => ['name' => '店员下单', 'description' => '由门店店员操作POS系统创建的订单'],
    2 => ['name' => '自助点单', 'description' => '顾客在店内通过自助终端创建的订单'],
    3 => ['name' => '扫码点单', 'description' => '顾客通过扫描桌面二维码创建的订单'],
    4 => ['name' => '外卖平台', 'description' => '通过第三方外卖平台接入的订单']
];

// 获取订单类型统计
try {
    if ($has_date_filter) {
        $sql = "
            SELECT order_type, COUNT(*) as order_count, SUM(total_amount) as total_amount 
            FROM order_main 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY order_type
        ";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    } else {
        $sql = "
            SELECT order_type, COUNT(*) as order_count, SUM(total_amount) as total_amount 
            FROM order_main 
            GROUP BY order_type
        ";
        $stmt = $pdo->query($sql);
    }

    $type_stats = [];
    while ($row = $stmt->fetch()) {
        $type_stats[$row['order_type']] = $row;
    }
} catch (PDOException $e) {
    $error = '获取订单类型统计失败：' . $e->getMessage();
    $type_stats = [];
}

// 获取订单来源统计
try {
    if ($has_date_filter) {
        $sql = "
            SELECT order_source, COUNT(*) as order_count, SUM(total_amount) as total_amount 
            FROM order_main 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY order_source
        ";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    } else {
        $sql = "
            SELECT order_source, COUNT(*) as order_count, SUM(total_amount) as total_amount 
            FROM order_main 
            GROUP BY order_source
        ";
        $stmt = $pdo->query($sql);
    }

    $source_stats = [];
    while ($row = $stmt->fetch()) {
        $source_stats[$row['order_source']] = $row;
    }
} catch (PDOException $e) {
    $error = '获取订单来源统计失败：' . $e->getMessage();
    $source_stats = [];
}

// 获取总订单数和金额（用于计算百分比）
try {
    if ($has_date_filter) {
        $sql = "
            SELECT COUNT(*) as total_orders, SUM(total_amount) as total_amount 
            FROM order_main 
            WHERE create_time BETWEEN ? AND ?
        ";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    } else {
        $sql = "
            SELECT COUNT(*) as total_orders, SUM(total_amount) as total_amount 
            FROM order_main
        ";
        $stmt = $pdo->query($sql);
    }

    $totals = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取订单总数统计失败：' . $e->getMessage();
    $totals = ['total_orders' => 0, 'total_amount' => 0];
}

// 获取各类型订单的每日统计（用于图表）
try {
    if ($has_date_filter) {
        $sql = "
            SELECT 
                DATE(create_time) as date, 
                order_type, 
                COUNT(*) as count 
            FROM order_main 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY DATE(create_time), order_type 
            ORDER BY DATE(create_time)
        ";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    } else {
        // 默认显示最近30天的每日统计
        $sql = "
            SELECT 
                DATE(create_time) as date, 
                order_type, 
                COUNT(*) as count 
            FROM order_main 
            WHERE create_time >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
            GROUP BY DATE(create_time), order_type 
            ORDER BY DATE(create_time)
        ";
        $stmt = $pdo->query($sql);
    }

    $daily_stats = [];
    while ($row = $stmt->fetch()) {
        if (!isset($daily_stats[$row['date']])) {
            $daily_stats[$row['date']] = [
                1 => 0,
                2 => 0,
                3 => 0
            ];
        }
        $daily_stats[$row['date']][$row['order_type']] = (int)$row['count'];
    }
} catch (PDOException $e) {
    $error = '获取每日订单统计失败：' . $e->getMessage();
    $daily_stats = [];
}

// 获取每个门店的订单类型分布
try {
    if ($has_date_filter) {
        $sql = "
            SELECT 
                s.id, 
                s.store_name,
                o.order_type, 
                COUNT(*) as order_count 
            FROM store_info s
            LEFT JOIN order_main o ON s.id = o.store_id AND o.create_time BETWEEN ? AND ?
            WHERE s.status = 1
            GROUP BY s.id, s.store_name, o.order_type
            ORDER BY s.id, o.order_type
        ";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    } else {
        $sql = "
            SELECT 
                s.id, 
                s.store_name,
                o.order_type, 
                COUNT(*) as order_count 
            FROM store_info s
            LEFT JOIN order_main o ON s.id = o.store_id
            WHERE s.status = 1
            GROUP BY s.id, s.store_name, o.order_type
            ORDER BY s.id, o.order_type
        ";
        $stmt = $pdo->query($sql);
    }

    $store_stats = [];
    while ($row = $stmt->fetch()) {
        if (!isset($store_stats[$row['id']])) {
            $store_stats[$row['id']] = [
                'store_name' => $row['store_name'],
                'types' => [
                    1 => 0,
                    2 => 0,
                    3 => 0
                ]
            ];
        }
        if ($row['order_type'] !== null) {
            $store_stats[$row['id']]['types'][$row['order_type']] = (int)$row['order_count'];
        }
    }
} catch (PDOException $e) {
    $error = '获取门店订单统计失败：' . $e->getMessage();
    $store_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单分类管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单与销售管理</a> &gt; 订单分类管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 时间筛选表单 -->
            <div class="filter-form">
                <form method="get">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="category.php" class="btn btn-secondary">显示全部</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 当前筛选状态 -->
            <?php if ($has_date_filter): ?>
                <div class="info-box">
                    <p>当前显示：<?php echo $start_date; ?> 至 <?php echo $end_date; ?> 的订单数据</p>
                </div>
            <?php else: ?>
                <div class="info-box">
                    <p>当前显示：全部订单数据（每日统计显示最近30天）</p>
                </div>
            <?php endif; ?>

            <!-- 订单类型统计 -->
            <h2>订单类型统计</h2>
            <div class="dashboard">
                <?php foreach ($order_types as $type_id => $type): ?>
                    <div class="dashboard-card">
                        <h3><?php echo $type['name']; ?></h3>
                        <div class="number">
                            <?php echo isset($type_stats[$type_id]) ? $type_stats[$type_id]['order_count'] : 0; ?>
                        </div>
                        <div class="desc">
                            金额：¥<?php echo isset($type_stats[$type_id]) ? number_format($type_stats[$type_id]['total_amount'], 2) : '0.00'; ?><br>
                            占比：<?php
                                if ($totals['total_orders'] > 0 && isset($type_stats[$type_id])) {
                                    echo round($type_stats[$type_id]['order_count'] / $totals['total_orders'] * 100, 2);
                                } else {
                                    echo '0';
                                }
                                ?>%<br>
                            <?php echo $type['description']; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

            <!-- 订单来源统计 -->
            <h2>订单来源统计</h2>
            <div class="dashboard">
                <?php foreach ($order_sources as $source_id => $source): ?>
                    <div class="dashboard-card">
                        <h3><?php echo $source['name']; ?></h3>
                        <div class="number">
                            <?php echo isset($source_stats[$source_id]) ? $source_stats[$source_id]['order_count'] : 0; ?>
                        </div>
                        <div class="desc">
                            金额：¥<?php echo isset($source_stats[$source_id]) ? number_format($source_stats[$source_id]['total_amount'], 2) : '0.00'; ?><br>
                            占比：<?php
                                if ($totals['total_orders'] > 0 && isset($source_stats[$source_id])) {
                                    echo round($source_stats[$source_id]['order_count'] / $totals['total_orders'] * 100, 2);
                                } else {
                                    echo '0';
                                }
                                ?>%<br>
                            <?php echo $source['description']; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

            <!-- 门店分类统计表 -->
            <h2>门店订单类型分布</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>门店名称</th>
                            <th>堂食订单数</th>
                            <th>外带订单数</th>
                            <th>外卖订单数</th>
                            <th>订单总数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($store_stats)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($store_stats as $store): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($store['store_name']); ?></td>
                                    <td><?php echo $store['types'][1]; ?></td>
                                    <td><?php echo $store['types'][2]; ?></td>
                                    <td><?php echo $store['types'][3]; ?></td>
                                    <td><?php echo array_sum($store['types']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 表格展示每日统计数据 -->
            <h2>每日订单类型统计</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <th>堂食订单数</th>
                            <th>外带订单数</th>
                            <th>外卖订单数</th>
                            <th>订单总数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($daily_stats)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($daily_stats as $date => $stats): ?>
                                <tr>
                                    <td><?php echo $date; ?></td>
                                    <td><?php echo $stats[1]; ?></td>
                                    <td><?php echo $stats[2]; ?></td>
                                    <td><?php echo $stats[3]; ?></td>
                                    <td><?php echo $stats[1] + $stats[2] + $stats[3]; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>