<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('statistics.customer');

// 记录访问日志
record_log('访问会员消费行为分析页面');

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_member_level = isset($_GET['member_level']) ? intval($_GET['member_level']) : 0;
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : ''; // 默认显示全部
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : ''; // 默认显示全部
$filter_sort = isset($_GET['sort']) ? trim($_GET['sort']) : 'frequency'; // 默认按消费频次排序
$filter_limit = isset($_GET['limit']) ? intval($_GET['limit']) : 10; // 默认显示前10名

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "o.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_member_level > 0) {
    $where[] = "m.level = ?";
    $params[] = $filter_member_level;
}

if (!empty($filter_start_date)) {
    $where[] = "o.create_time >= ?";
    $params[] = $filter_start_date . ' 00:00:00';
}

if (!empty($filter_end_date)) {
    $where[] = "o.create_time <= ?";
    $params[] = $filter_end_date . ' 23:59:59';
}

// 默认条件：只统计有效会员和已完成的订单
$where[] = "m.status = 1"; // 有效会员
$where[] = "o.status IN (3, 4)"; // 已完成或已取餐的订单

// 获取活跃会员数据
try {
    $sql = "
        SELECT 
            m.id AS member_id,
            m.member_no,
            m.name AS member_name,
            m.phone,
            m.level,
            COUNT(DISTINCT o.id) AS order_count,
            SUM(o.total_amount) AS total_amount,
            AVG(o.total_amount) AS avg_amount,
            MAX(o.create_time) AS last_order_time,
            COUNT(DISTINCT DATE(o.create_time)) AS visit_days
        FROM 
            mem_info m
            JOIN order_main o ON m.id = o.member_id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " 
        GROUP BY 
            m.id
        ORDER BY 
    ";

    // 排序方式
    if ($filter_sort == 'amount') {
        $sql .= " total_amount DESC";
    } else {
        $sql .= " order_count DESC";
    }

    // 直接将LIMIT值嵌入SQL中，避免参数绑定问题
    $sql .= " LIMIT " . intval($filter_limit);

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $active_members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活跃会员数据失败：' . $e->getMessage();
    $active_members = [];
}

// 获取会员总览统计数据
try {
    // 使用新的参数数组
    $stats_params = $params;

    $stats_sql = "
        SELECT 
            COUNT(DISTINCT m.id) AS total_members,
            SUM(CASE WHEN o.id IS NOT NULL THEN 1 ELSE 0 END) AS total_orders,
            SUM(o.total_amount) AS total_amount,
            AVG(o.total_amount) AS avg_order_amount,
            COUNT(DISTINCT o.member_id) AS active_members
        FROM 
            mem_info m
            LEFT JOIN order_main o ON m.id = o.member_id
    ";

    $stats_where = $where;
    if (!empty($stats_where)) {
        $stats_sql .= " WHERE " . implode(' AND ', $stats_where);
    }

    $stmt = $pdo->prepare($stats_sql);
    $stmt->execute($stats_params);
    $member_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取会员统计数据失败：' . $e->getMessage();
    $member_stats = [
        'total_members' => 0,
        'total_orders' => 0,
        'total_amount' => 0,
        'avg_order_amount' => 0,
        'active_members' => 0
    ];
}

// 获取会员等级分布
try {
    $level_params = $params;

    $level_sql = "
        SELECT 
            m.level,
            COUNT(DISTINCT m.id) AS member_count,
            SUM(o.total_amount) AS level_amount,
            COUNT(DISTINCT o.id) AS order_count
        FROM 
            mem_info m
            JOIN order_main o ON m.id = o.member_id
    ";

    $level_where = $where;
    if (!empty($level_where)) {
        $level_sql .= " WHERE " . implode(' AND ', $level_where);
    }

    $level_sql .= " GROUP BY m.level ORDER BY m.level";

    $stmt = $pdo->prepare($level_sql);
    $stmt->execute($level_params);
    $level_stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员等级分布数据失败：' . $e->getMessage();
    $level_stats = [];
}

// 获取会员最喜爱的产品类别
try {
    $category_params = $params;

    $category_sql = "
        SELECT 
            pc.id AS category_id,
            pc.name AS category_name,
            COUNT(DISTINCT o.member_id) AS member_count,
            COUNT(oi.id) AS item_count,
            SUM(oi.quantity) AS total_quantity
        FROM 
            order_item oi
            JOIN order_main o ON oi.order_id = o.id
            JOIN product_items p ON oi.product_id = p.id
            JOIN product_category pc ON p.category = pc.id
            JOIN mem_info m ON o.member_id = m.id
    ";

    $category_where = $where;
    if (!empty($category_where)) {
        $category_sql .= " WHERE " . implode(' AND ', $category_where);
    }

    $category_sql .= " 
        GROUP BY 
            pc.id
        ORDER BY 
            member_count DESC
    ";

    $stmt = $pdo->prepare($category_sql);
    $stmt->execute($category_params);
    $favorite_categories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员最喜爱产品类别数据失败：' . $e->getMessage();
    $favorite_categories = [];
}

// 获取会员消费时段分布
try {
    $time_params = $params;

    $time_sql = "
        SELECT 
            HOUR(o.create_time) AS hour_of_day,
            COUNT(DISTINCT o.id) AS order_count,
            COUNT(DISTINCT o.member_id) AS member_count,
            SUM(o.total_amount) AS total_amount
        FROM 
            order_main o
            JOIN mem_info m ON o.member_id = m.id
    ";

    $time_where = $where;
    if (!empty($time_where)) {
        $time_sql .= " WHERE " . implode(' AND ', $time_where);
    }

    $time_sql .= " 
        GROUP BY 
            HOUR(o.create_time)
        ORDER BY 
            HOUR(o.create_time)
    ";

    $stmt = $pdo->prepare($time_sql);
    $stmt->execute($time_params);
    $time_distribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员消费时段分布数据失败：' . $e->getMessage();
    $time_distribution = [];
}

// 获取会员最常购买的产品
try {
    $product_params = $params;

    $product_sql = "
        SELECT 
            p.id AS product_id,
            p.name AS product_name,
            pc.name AS category_name,
            COUNT(DISTINCT o.member_id) AS member_count,
            SUM(oi.quantity) AS total_quantity,
            COUNT(DISTINCT o.id) AS order_count
        FROM 
            order_item oi
            JOIN order_main o ON oi.order_id = o.id
            JOIN product_items p ON oi.product_id = p.id
            JOIN product_category pc ON p.category = pc.id
            JOIN mem_info m ON o.member_id = m.id
    ";

    $product_where = $where;
    if (!empty($product_where)) {
        $product_sql .= " WHERE " . implode(' AND ', $product_where);
    }

    $product_sql .= " 
        GROUP BY 
            p.id
        ORDER BY 
            member_count DESC
        LIMIT 10
    ";

    $stmt = $pdo->prepare($product_sql);
    $stmt->execute($product_params);
    $popular_products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员最常购买产品数据失败：' . $e->getMessage();
    $popular_products = [];
}

// 计算会员等级名称
function getMemberLevelName($level)
{
    switch ($level) {
        case 1:
            return '普通会员';
        case 2:
            return '银卡会员';
        case 3:
            return '金卡会员';
        case 4:
            return '黑卡会员';
        default:
            return '未知等级';
    }
}

// 处理会员数据更新请求
if (isset($_POST['update_member'])) {
    $update_store_id = isset($_POST['update_store_id']) ? intval($_POST['update_store_id']) : 0;
    $update_year = isset($_POST['update_year']) ? intval($_POST['update_year']) : date('Y');
    $update_month = isset($_POST['update_month']) ? intval($_POST['update_month']) : date('n');

    try {
        // 设置统计周期
        $period = $update_year . '-' . str_pad($update_month, 2, '0', STR_PAD_LEFT);
        $start_date = $period . '-01';
        $end_date = date('Y-m-t', strtotime($start_date));

        // 准备查询条件
        $where_store = $update_store_id > 0 ? "AND o.store_id = " . $update_store_id : "";

        // 获取会员消费数据
        $member_sql = "
            SELECT 
                o.member_id,
                o.store_id,
                COUNT(DISTINCT o.id) AS visit_count,
                SUM(o.total_amount) AS total_amount
            FROM 
                order_main o
            WHERE 
                o.create_time BETWEEN ? AND ?
                AND o.member_id > 0
                AND o.status IN (3, 4)
                $where_store
            GROUP BY 
                o.member_id, o.store_id
        ";

        $stmt = $pdo->prepare($member_sql);
        $stmt->execute([
            $start_date . ' 00:00:00',
            $end_date . ' 23:59:59'
        ]);

        $member_data = $stmt->fetchAll();
        $updated_count = 0;

        // 更新或插入会员消费数据
        foreach ($member_data as $item) {
            $member_id = $item['member_id'];
            $store_id = $item['store_id'];
            $visit_count = $item['visit_count'];
            $total_amount = $item['total_amount'];
            $avg_amount = $visit_count > 0 ? ($total_amount / $visit_count) : 0;

            // 获取会员最常购买的产品
            $fav_product_sql = "
                SELECT 
                    oi.product_id,
                    MAX(oi.product_name) AS product_name,
                    MAX(pc.name) AS category_name,
                    COUNT(oi.id) AS buy_count
                FROM 
                    order_item oi
                    JOIN order_main o ON oi.order_id = o.id
                    JOIN product_items p ON oi.product_id = p.id
                    JOIN product_category pc ON p.category = pc.id
                WHERE 
                    o.member_id = ?
                    AND o.store_id = ?
                    AND o.create_time BETWEEN ? AND ?
                    AND o.status IN (3, 4)
                GROUP BY 
                    oi.product_id
                ORDER BY 
                    buy_count DESC, SUM(oi.quantity) DESC
                LIMIT 1
            ";

            $fav_stmt = $pdo->prepare($fav_product_sql);
            $fav_stmt->execute([
                $member_id,
                $store_id,
                $start_date . ' 00:00:00',
                $end_date . ' 23:59:59'
            ]);

            $fav_product = $fav_stmt->fetch();
            $fav_product_id = $fav_product ? $fav_product['product_id'] : null;
            $fav_product_name = $fav_product ? $fav_product['product_name'] : null;
            $fav_category = $fav_product ? $fav_product['category_name'] : null;

            // 检查是否已存在该会员该周期的消费记录
            $check_sql = "
                SELECT id FROM rpt_member 
                WHERE member_id = ? AND store_id = ? AND period = ?
            ";
            $check_stmt = $pdo->prepare($check_sql);
            $check_stmt->execute([$member_id, $store_id, $period]);
            $exists = $check_stmt->fetch();

            if ($exists) {
                // 更新现有记录
                $update_sql = "
                    UPDATE rpt_member SET
                        visit_count = ?,
                        total_amount = ?,
                        avg_amount = ?,
                        fav_product_id = ?,
                        fav_product_name = ?,
                        fav_category = ?
                    WHERE id = ?
                ";
                $update_stmt = $pdo->prepare($update_sql);
                $update_stmt->execute([
                    $visit_count,
                    $total_amount,
                    $avg_amount,
                    $fav_product_id,
                    $fav_product_name,
                    $fav_category,
                    $exists['id']
                ]);
            } else {
                // 添加新记录
                $insert_sql = "
                    INSERT INTO rpt_member (
                        member_id, store_id, period,
                        visit_count, total_amount, avg_amount,
                        fav_product_id, fav_product_name, fav_category
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
                ";
                $insert_stmt = $pdo->prepare($insert_sql);
                $insert_stmt->execute([
                    $member_id,
                    $store_id,
                    $period,
                    $visit_count,
                    $total_amount,
                    $avg_amount,
                    $fav_product_id,
                    $fav_product_name,
                    $fav_category
                ]);
            }

            $updated_count++;
        }

        $success = "成功更新{$updated_count}条会员消费数据";
        record_log("更新{$period}期间的会员消费统计数据");
    } catch (PDOException $e) {
        $error = '更新会员数据失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员消费行为分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 会员消费行为分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 更新会员数据表单 -->
            <div class="form-container">
                <h3>更新会员消费数据</h3>
                <form method="post" action="">
                    <div class="form-row">
                        <div class="filter-item">
                            <label for="update_store_id">门店：</label>
                            <select id="update_store_id" name="update_store_id">
                                <option value="0">所有门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_year">年份：</label>
                            <select id="update_year" name="update_year">
                                <?php
                                $current_year = date('Y');
                                for ($y = $current_year; $y >= 2020; $y--):
                                ?>
                                    <option value="<?php echo $y; ?>"><?php echo $y; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_month">月份：</label>
                            <select id="update_month" name="update_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo (intval(date('n')) == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" name="update_member" value="1" class="btn btn-success">更新会员数据</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="member_level">会员等级：</label>
                            <select id="member_level" name="member_level">
                                <option value="0">全部等级</option>
                                <option value="1" <?php echo ($filter_member_level == 1) ? 'selected' : ''; ?>>普通会员</option>
                                <option value="2" <?php echo ($filter_member_level == 2) ? 'selected' : ''; ?>>银卡会员</option>
                                <option value="3" <?php echo ($filter_member_level == 3) ? 'selected' : ''; ?>>金卡会员</option>
                                <option value="4" <?php echo ($filter_member_level == 4) ? 'selected' : ''; ?>>黑卡会员</option>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="sort">排序方式：</label>
                            <select id="sort" name="sort">
                                <option value="frequency" <?php echo ($filter_sort == 'frequency') ? 'selected' : ''; ?>>按消费频次排序</option>
                                <option value="amount" <?php echo ($filter_sort == 'amount') ? 'selected' : ''; ?>>按消费金额排序</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="limit">显示数量：</label>
                            <select id="limit" name="limit">
                                <option value="10" <?php echo ($filter_limit == 10) ? 'selected' : ''; ?>>前10名</option>
                                <option value="20" <?php echo ($filter_limit == 20) ? 'selected' : ''; ?>>前20名</option>
                                <option value="50" <?php echo ($filter_limit == 50) ? 'selected' : ''; ?>>前50名</option>
                                <option value="100" <?php echo ($filter_limit == 100) ? 'selected' : ''; ?>>前100名</option>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">查询</button>
                            <a href="customer.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 会员统计摘要 -->
            <div class="info-box">
                <h3>会员统计摘要（<?php echo empty($filter_start_date) && empty($filter_end_date) ? '全部数据' : $filter_start_date . ' 至 ' . $filter_end_date; ?>）</h3>
                <ul>
                    <li>活跃会员数：<?php echo isset($member_stats['active_members']) ? $member_stats['active_members'] : 0; ?></li>
                    <li>会员总订单数：<?php echo isset($member_stats['total_orders']) ? $member_stats['total_orders'] : 0; ?></li>
                    <li>会员消费总额：￥<?php echo isset($member_stats['total_amount']) ? number_format($member_stats['total_amount'], 2) : '0.00'; ?></li>
                    <li>会员平均客单价：￥<?php echo isset($member_stats['avg_order_amount']) ? number_format($member_stats['avg_order_amount'], 2) : '0.00'; ?></li>
                </ul>
            </div>

            <!-- 活跃会员列表 -->
            <div class="table-container">
                <h3>活跃会员排行（<?php echo $filter_sort == 'frequency' ? '按消费频次' : '按消费金额'; ?>）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>会员编号</th>
                            <th>会员姓名</th>
                            <th>联系电话</th>
                            <th>会员等级</th>
                            <th>消费次数</th>
                            <th>消费总额</th>
                            <th>平均客单价</th>
                            <th>最近消费时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($active_members)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无会员消费数据</td>
                            </tr>
                        <?php else: ?>
                            <?php $rank = 1;
                            foreach ($active_members as $member): ?>
                                <tr>
                                    <td><?php echo $rank++; ?></td>
                                    <td><?php echo htmlspecialchars($member['member_no']); ?></td>
                                    <td><?php echo htmlspecialchars($member['member_name']); ?></td>
                                    <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                    <td><?php echo getMemberLevelName($member['level']); ?></td>
                                    <td><?php echo $member['order_count']; ?></td>
                                    <td>￥<?php echo number_format($member['total_amount'], 2); ?></td>
                                    <td>￥<?php echo number_format($member['avg_amount'], 2); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($member['last_order_time'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 会员等级分布 -->
            <div class="table-container">
                <h3>会员等级消费分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>会员等级</th>
                            <th>会员数量</th>
                            <th>消费总额</th>
                            <th>订单数量</th>
                            <th>人均消费</th>
                            <th>占总消费比例</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($level_stats)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无会员等级分布数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total_consumption = isset($member_stats['total_amount']) ? $member_stats['total_amount'] : 0;
                            foreach ($level_stats as $level): ?>
                                <tr>
                                    <td><?php echo getMemberLevelName($level['level']); ?></td>
                                    <td><?php echo $level['member_count']; ?></td>
                                    <td>￥<?php echo number_format($level['level_amount'], 2); ?></td>
                                    <td><?php echo $level['order_count']; ?></td>
                                    <td>￥<?php echo $level['member_count'] > 0 ? number_format($level['level_amount'] / $level['member_count'], 2) : '0.00'; ?></td>
                                    <td><?php echo $total_consumption > 0 ? number_format(($level['level_amount'] / $total_consumption) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 会员最喜爱的产品类别 -->
            <div class="table-container">
                <h3>会员最喜爱的产品类别</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>类别名称</th>
                            <th>消费会员数</th>
                            <th>订单项数量</th>
                            <th>销售数量</th>
                            <th>会员覆盖率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($favorite_categories)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无会员产品偏好数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total_active_members = isset($member_stats['active_members']) ? $member_stats['active_members'] : 0;
                            foreach ($favorite_categories as $category): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($category['category_name']); ?></td>
                                    <td><?php echo $category['member_count']; ?></td>
                                    <td><?php echo $category['item_count']; ?></td>
                                    <td><?php echo $category['total_quantity']; ?></td>
                                    <td><?php echo $total_active_members > 0 ? number_format(($category['member_count'] / $total_active_members) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 会员最常购买的产品 -->
            <div class="table-container">
                <h3>会员最常购买的产品</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>所属类别</th>
                            <th>消费会员数</th>
                            <th>销售数量</th>
                            <th>订单数量</th>
                            <th>会员覆盖率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($popular_products)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无会员产品消费数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total_active_members = isset($member_stats['active_members']) ? $member_stats['active_members'] : 0;
                            foreach ($popular_products as $product): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                                    <td><?php echo htmlspecialchars($product['category_name']); ?></td>
                                    <td><?php echo $product['member_count']; ?></td>
                                    <td><?php echo $product['total_quantity']; ?></td>
                                    <td><?php echo $product['order_count']; ?></td>
                                    <td><?php echo $total_active_members > 0 ? number_format(($product['member_count'] / $total_active_members) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 会员消费时段分布 -->
            <div class="table-container">
                <h3>会员消费时段分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>时段</th>
                            <th>订单数量</th>
                            <th>消费会员数</th>
                            <th>消费金额</th>
                            <th>占总订单比例</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($time_distribution)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无会员消费时段数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total_orders = isset($member_stats['total_orders']) ? $member_stats['total_orders'] : 0;
                            foreach ($time_distribution as $time): ?>
                                <tr>
                                    <td><?php echo str_pad($time['hour_of_day'], 2, '0', STR_PAD_LEFT) . ':00-' . str_pad($time['hour_of_day'] + 1, 2, '0', STR_PAD_LEFT) . ':00'; ?></td>
                                    <td><?php echo $time['order_count']; ?></td>
                                    <td><?php echo $time['member_count']; ?></td>
                                    <td>￥<?php echo number_format($time['total_amount'], 2); ?></td>
                                    <td><?php echo $total_orders > 0 ? number_format(($time['order_count'] / $total_orders) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>