<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('statistics.kpi');

// 记录访问日志
record_log('访问运营KPI统计页面');

// 处理KPI数据更新请求
if (isset($_POST['update_kpi'])) {
    $year = isset($_POST['update_year']) ? intval($_POST['update_year']) : date('Y');
    $month = isset($_POST['update_month']) ? intval($_POST['update_month']) : date('n');
    $store_id = isset($_POST['update_store_id']) ? intval($_POST['update_store_id']) : 0;

    try {
        // 设置统计周期
        $period = $year . '-' . str_pad($month, 2, '0', STR_PAD_LEFT);
        $start_date = $period . '-01';
        $end_date = date('Y-m-t', strtotime($start_date));

        // 准备查询条件
        $where_store = $store_id > 0 ? "AND store_id = " . $store_id : "";

        // 计算上一个月的周期，用于计算环比增长
        $prev_month = $month - 1;
        $prev_year = $year;
        if ($prev_month <= 0) {
            $prev_month += 12;
            $prev_year -= 1;
        }
        $prev_period = $prev_year . '-' . str_pad($prev_month, 2, '0', STR_PAD_LEFT);

        // 统计各门店的KPI数据
        if ($store_id > 0) {
            $store_query = "SELECT id FROM store_info WHERE id = $store_id";
        } else {
            $store_query = "SELECT id FROM store_info";
        }

        $stores = $pdo->query($store_query)->fetchAll(PDO::FETCH_COLUMN);

        $updated_count = 0;

        foreach ($stores as $current_store_id) {
            // 获取当月订单数据
            $order_query = $pdo->prepare("
                SELECT 
                    COUNT(id) as order_count,
                    COUNT(DISTINCT member_id) as customer_count,
                    IFNULL(SUM(total_amount), 0) as revenue,
                    IFNULL(SUM(IF(member_id > 0, total_amount, 0)), 0) as member_amount
                FROM 
                    order_main
                WHERE 
                    create_time BETWEEN ? AND ?
                    AND store_id = ?
                    AND status IN (3, 4)
            ");

            $order_query->execute([
                $start_date . ' 00:00:00',
                $end_date . ' 23:59:59',
                $current_store_id
            ]);

            $order_data = $order_query->fetch();

            // 获取上个月的营业额，用于计算环比增长
            $prev_query = $pdo->prepare("
                SELECT 
                    SUM(total_amount) as prev_revenue
                FROM 
                    order_main
                WHERE 
                    DATE_FORMAT(create_time, '%Y-%m') = ?
                    AND store_id = ?
                    AND status IN (3, 4)
            ");

            $prev_query->execute([$prev_period, $current_store_id]);
            $prev_data = $prev_query->fetch();

            // 计算营收增长率
            $revenue_growth = 0;
            if ($prev_data && $prev_data['prev_revenue'] > 0) {
                $revenue_growth = (($order_data['revenue'] - $prev_data['prev_revenue']) / $prev_data['prev_revenue']) * 100;
            }

            // 获取新增会员数
            $member_query = $pdo->prepare("
                SELECT 
                    COUNT(id) as new_member_count
                FROM 
                    mem_info
                WHERE 
                    DATE_FORMAT(create_time, '%Y-%m') = ?
            ");

            $member_query->execute([$period]);
            $member_data = $member_query->fetch();

            // 计算毛利润（假设有成本数据，这里简化处理，设定毛利率为60%）
            $gross_profit_rate = 60.0; // 假设毛利率为60%
            $gross_profit = $order_data['revenue'] * ($gross_profit_rate / 100);

            // 计算会员消费占比
            $member_ratio = 0;
            if ($order_data['revenue'] > 0) {
                $member_ratio = ($order_data['member_amount'] / $order_data['revenue']) * 100;
            }

            // 检查该月是否已有数据
            $check_query = $pdo->prepare("
                SELECT id FROM rpt_kpi 
                WHERE store_id = ? AND period = ?
            ");

            $check_query->execute([$current_store_id, $period]);
            $exists = $check_query->fetch();

            if ($exists) {
                // 更新现有记录
                $update_query = $pdo->prepare("
                    UPDATE rpt_kpi SET
                        order_count = ?,
                        customer_count = ?,
                        revenue = ?,
                        revenue_growth = ?,
                        gross_profit = ?,
                        gross_profit_rate = ?,
                        new_member_count = ?,
                        member_amount = ?,
                        member_ratio = ?
                    WHERE 
                        store_id = ? AND period = ?
                ");

                $update_query->execute([
                    $order_data['order_count'],
                    $order_data['customer_count'],
                    $order_data['revenue'],
                    $revenue_growth,
                    $gross_profit,
                    $gross_profit_rate,
                    $member_data['new_member_count'],
                    $order_data['member_amount'],
                    $member_ratio,
                    $current_store_id,
                    $period
                ]);
            } else {
                // 添加新记录
                $insert_query = $pdo->prepare("
                    INSERT INTO rpt_kpi (
                        store_id, period, order_count, customer_count, revenue,
                        revenue_growth, gross_profit, gross_profit_rate,
                        new_member_count, member_amount, member_ratio
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");

                $insert_query->execute([
                    $current_store_id,
                    $period,
                    $order_data['order_count'],
                    $order_data['customer_count'],
                    $order_data['revenue'],
                    $revenue_growth,
                    $gross_profit,
                    $gross_profit_rate,
                    $member_data['new_member_count'],
                    $order_data['member_amount'],
                    $member_ratio
                ]);
            }

            $updated_count++;
        }

        $success = "成功更新{$updated_count}条KPI数据";
        record_log("更新{$period}期间的KPI数据");
    } catch (PDOException $e) {
        $error = '更新KPI数据失败：' . $e->getMessage();
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : 0; // 0表示全部年份
$filter_start_month = isset($_GET['start_month']) ? intval($_GET['start_month']) : 1;
$filter_end_month = isset($_GET['end_month']) ? intval($_GET['end_month']) : 12;
$filter_compare = isset($_GET['compare']) ? intval($_GET['compare']) : 0; // 0=不比较，1=同比，2=环比

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取可用的年份列表
try {
    $stmt = $pdo->query("SELECT DISTINCT SUBSTRING(period, 1, 4) as year FROM rpt_kpi ORDER BY year DESC");
    $available_years = $stmt->fetchAll(PDO::FETCH_COLUMN);
    if (empty($available_years)) {
        $available_years = [date('Y')];
    }
} catch (PDOException $e) {
    $error = '获取年份列表失败：' . $e->getMessage();
    $available_years = [date('Y')];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "rk.store_id = ?";
    $params[] = $filter_store_id;
}

// 构建周期条件
if ($filter_year > 0) {
    // 特定年份的月份范围
    $period_condition = [];
    for ($i = $filter_start_month; $i <= $filter_end_month; $i++) {
        $month = str_pad($i, 2, '0', STR_PAD_LEFT);
        $period_condition[] = "rk.period = ?";
        $params[] = "{$filter_year}-{$month}";
    }

    if (!empty($period_condition)) {
        $where[] = "(" . implode(' OR ', $period_condition) . ")";
    }
} else {
    // 全部年份，但限制月份范围
    $month_condition = [];
    for ($i = $filter_start_month; $i <= $filter_end_month; $i++) {
        $month = str_pad($i, 2, '0', STR_PAD_LEFT);
        $month_condition[] = "SUBSTRING(rk.period, 6, 2) = ?";
        $params[] = $month;
    }

    if (!empty($month_condition)) {
        $where[] = "(" . implode(' OR ', $month_condition) . ")";
    }
}

// 获取KPI数据
try {
    $sql = "
        SELECT 
            rk.*,
            s.store_name
        FROM 
            rpt_kpi rk
            JOIN store_info s ON rk.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY rk.period ASC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $kpi_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取KPI数据失败：' . $e->getMessage();
    $kpi_data = [];
}

// 获取同比或环比数据
$compare_data = [];
if ($filter_compare > 0) {
    try {
        $compare_where = [];
        $compare_params = [];

        if ($filter_store_id > 0) {
            $compare_where[] = "rk.store_id = ?";
            $compare_params[] = $filter_store_id;
        }

        // 同比：去年同期
        if ($filter_compare == 1) {
            if ($filter_year > 0) {
                $compare_year = $filter_year - 1;
                $period_condition = [];

                for ($i = $filter_start_month; $i <= $filter_end_month; $i++) {
                    $month = str_pad($i, 2, '0', STR_PAD_LEFT);
                    $period_condition[] = "rk.period = ?";
                    $compare_params[] = "{$compare_year}-{$month}";
                }

                if (!empty($period_condition)) {
                    $compare_where[] = "(" . implode(' OR ', $period_condition) . ")";
                }
            } else {
                // 全部年份的同比处理（这里可以根据需求调整）
                $month_condition = [];
                for ($i = $filter_start_month; $i <= $filter_end_month; $i++) {
                    $month = str_pad($i, 2, '0', STR_PAD_LEFT);
                    $month_condition[] = "SUBSTRING(rk.period, 6, 2) = ?";
                    $compare_params[] = $month;
                }

                if (!empty($month_condition)) {
                    $compare_where[] = "(" . implode(' OR ', $month_condition) . ")";
                }

                // 查询上一年的数据
                $compare_where[] = "SUBSTRING(rk.period, 1, 4) < SUBSTRING(NOW(), 1, 4)";
            }
        }
        // 环比：上月
        else if ($filter_compare == 2) {
            $compare_month_start = $filter_start_month - 1;
            $compare_month_end = $filter_end_month - 1;
            $compare_year = $filter_year;

            // 处理跨年的情况
            if ($compare_month_start < 1) {
                $compare_month_start += 12;
                if ($filter_year > 0) $compare_year--;
            }
            if ($compare_month_end < 1) {
                $compare_month_end += 12;
                if ($filter_year > 0) $compare_year--;
            }

            if ($filter_year > 0) {
                $period_condition = [];
                for ($i = $compare_month_start; $i <= $compare_month_end; $i++) {
                    $month = str_pad($i, 2, '0', STR_PAD_LEFT);
                    $period_condition[] = "rk.period = ?";
                    $compare_params[] = "{$compare_year}-{$month}";
                }

                if (!empty($period_condition)) {
                    $compare_where[] = "(" . implode(' OR ', $period_condition) . ")";
                }
            } else {
                // 全部年份的环比处理
                $month_condition = [];
                for ($i = $compare_month_start; $i <= $compare_month_end; $i++) {
                    $real_month = $i;
                    if ($real_month < 1) {
                        $real_month += 12;
                    }
                    $month = str_pad($real_month, 2, '0', STR_PAD_LEFT);
                    $month_condition[] = "SUBSTRING(rk.period, 6, 2) = ?";
                    $compare_params[] = $month;
                }

                if (!empty($month_condition)) {
                    $compare_where[] = "(" . implode(' OR ', $month_condition) . ")";
                }
            }
        }

        $sql = "
            SELECT 
                rk.*,
                s.store_name
            FROM 
                rpt_kpi rk
                JOIN store_info s ON rk.store_id = s.id
        ";

        if (!empty($compare_where)) {
            $sql .= " WHERE " . implode(' AND ', $compare_where);
        }

        $sql .= " ORDER BY rk.period ASC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($compare_params);
        $compare_data = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取比较数据失败：' . $e->getMessage();
        $compare_data = [];
    }
}

// 计算KPI总计和平均值
$kpi_summary = [
    'total_order_count' => 0,
    'total_customer_count' => 0,
    'total_revenue' => 0,
    'avg_revenue_growth' => 0,
    'total_gross_profit' => 0,
    'avg_gross_profit_rate' => 0,
    'total_new_member_count' => 0,
    'total_member_amount' => 0,
    'avg_member_ratio' => 0
];

$non_zero_months = 0;
foreach ($kpi_data as $item) {
    $kpi_summary['total_order_count'] += $item['order_count'];
    $kpi_summary['total_customer_count'] += $item['customer_count'];
    $kpi_summary['total_revenue'] += $item['revenue'];
    $kpi_summary['total_gross_profit'] += $item['gross_profit'];
    $kpi_summary['total_new_member_count'] += $item['new_member_count'];
    $kpi_summary['total_member_amount'] += $item['member_amount'];

    if ($item['revenue_growth'] !== null) {
        $kpi_summary['avg_revenue_growth'] += $item['revenue_growth'];
    }

    if ($item['gross_profit_rate'] > 0) {
        $kpi_summary['avg_gross_profit_rate'] += $item['gross_profit_rate'];
    }

    if ($item['member_ratio'] > 0) {
        $kpi_summary['avg_member_ratio'] += $item['member_ratio'];
    }

    $non_zero_months++;
}

if ($non_zero_months > 0) {
    $kpi_summary['avg_revenue_growth'] /= $non_zero_months;
    $kpi_summary['avg_gross_profit_rate'] /= $non_zero_months;
    $kpi_summary['avg_member_ratio'] /= $non_zero_months;
}

// 计算比较数据总计和平均值
$compare_summary = [
    'total_order_count' => 0,
    'total_customer_count' => 0,
    'total_revenue' => 0,
    'avg_revenue_growth' => 0,
    'total_gross_profit' => 0,
    'avg_gross_profit_rate' => 0,
    'total_new_member_count' => 0,
    'total_member_amount' => 0,
    'avg_member_ratio' => 0
];

$non_zero_months = 0;
foreach ($compare_data as $item) {
    $compare_summary['total_order_count'] += $item['order_count'];
    $compare_summary['total_customer_count'] += $item['customer_count'];
    $compare_summary['total_revenue'] += $item['revenue'];
    $compare_summary['total_gross_profit'] += $item['gross_profit'];
    $compare_summary['total_new_member_count'] += $item['new_member_count'];
    $compare_summary['total_member_amount'] += $item['member_amount'];

    if ($item['revenue_growth'] !== null) {
        $compare_summary['avg_revenue_growth'] += $item['revenue_growth'];
    }

    if ($item['gross_profit_rate'] > 0) {
        $compare_summary['avg_gross_profit_rate'] += $item['gross_profit_rate'];
    }

    if ($item['member_ratio'] > 0) {
        $compare_summary['avg_member_ratio'] += $item['member_ratio'];
    }

    $non_zero_months++;
}

if ($non_zero_months > 0) {
    $compare_summary['avg_revenue_growth'] /= $non_zero_months;
    $compare_summary['avg_gross_profit_rate'] /= $non_zero_months;
    $compare_summary['avg_member_ratio'] /= $non_zero_months;
}

// 计算同比/环比变化率
$change_rate = [
    'order_count' => 0,
    'customer_count' => 0,
    'revenue' => 0,
    'revenue_growth' => 0,
    'gross_profit' => 0,
    'gross_profit_rate' => 0,
    'new_member_count' => 0,
    'member_amount' => 0,
    'member_ratio' => 0
];

if (!empty($compare_data)) {
    if ($compare_summary['total_order_count'] > 0) {
        $change_rate['order_count'] = (($kpi_summary['total_order_count'] - $compare_summary['total_order_count']) / $compare_summary['total_order_count']) * 100;
    }

    if ($compare_summary['total_customer_count'] > 0) {
        $change_rate['customer_count'] = (($kpi_summary['total_customer_count'] - $compare_summary['total_customer_count']) / $compare_summary['total_customer_count']) * 100;
    }

    if ($compare_summary['total_revenue'] > 0) {
        $change_rate['revenue'] = (($kpi_summary['total_revenue'] - $compare_summary['total_revenue']) / $compare_summary['total_revenue']) * 100;
    }

    if ($compare_summary['avg_revenue_growth'] != 0) {
        $change_rate['revenue_growth'] = $kpi_summary['avg_revenue_growth'] - $compare_summary['avg_revenue_growth'];
    }

    if ($compare_summary['total_gross_profit'] > 0) {
        $change_rate['gross_profit'] = (($kpi_summary['total_gross_profit'] - $compare_summary['total_gross_profit']) / $compare_summary['total_gross_profit']) * 100;
    }

    if ($compare_summary['avg_gross_profit_rate'] != 0) {
        $change_rate['gross_profit_rate'] = $kpi_summary['avg_gross_profit_rate'] - $compare_summary['avg_gross_profit_rate'];
    }

    if ($compare_summary['total_new_member_count'] > 0) {
        $change_rate['new_member_count'] = (($kpi_summary['total_new_member_count'] - $compare_summary['total_new_member_count']) / $compare_summary['total_new_member_count']) * 100;
    }

    if ($compare_summary['total_member_amount'] > 0) {
        $change_rate['member_amount'] = (($kpi_summary['total_member_amount'] - $compare_summary['total_member_amount']) / $compare_summary['total_member_amount']) * 100;
    }

    if ($compare_summary['avg_member_ratio'] != 0) {
        $change_rate['member_ratio'] = $kpi_summary['avg_member_ratio'] - $compare_summary['avg_member_ratio'];
    }
}

// 获取最新的营业数据（近30天）
try {
    $today = date('Y-m-d');
    $thirty_days_ago = date('Y-m-d', strtotime('-30 days'));

    $recent_sql = "
        SELECT 
            COUNT(id) AS recent_orders,
            SUM(total_amount) AS recent_revenue,
            COUNT(DISTINCT member_id) AS recent_members
        FROM 
            order_main
        WHERE 
            status IN (3, 4)
            AND create_time BETWEEN ? AND ?
    ";

    if ($filter_store_id > 0) {
        $recent_sql .= " AND store_id = ?";
        $recent_params = [$thirty_days_ago . ' 00:00:00', $today . ' 23:59:59', $filter_store_id];
    } else {
        $recent_params = [$thirty_days_ago . ' 00:00:00', $today . ' 23:59:59'];
    }

    $stmt = $pdo->prepare($recent_sql);
    $stmt->execute($recent_params);
    $recent_data = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取最近营业数据失败：' . $e->getMessage();
    $recent_data = [
        'recent_orders' => 0,
        'recent_revenue' => 0,
        'recent_members' => 0
    ];
}

// 获取每个门店的KPI排名
try {
    $rank_sql = "
        SELECT 
            s.id AS store_id,
            s.store_name,
            SUM(rk.order_count) AS total_orders,
            SUM(rk.revenue) AS total_revenue,
            SUM(rk.gross_profit) AS total_profit
        FROM 
            rpt_kpi rk
            JOIN store_info s ON rk.store_id = s.id
    ";

    if ($filter_year > 0) {
        $rank_sql .= " WHERE rk.period LIKE ?";
        $rank_params = [$filter_year . '%'];
    } else {
        // 如果选择全部年份，不添加年份条件
        $rank_params = [];
    }

    $rank_sql .= " GROUP BY s.id ORDER BY total_revenue DESC";

    $stmt = $pdo->prepare($rank_sql);
    $stmt->execute($rank_params);
    $store_rankings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店排名数据失败：' . $e->getMessage();
    $store_rankings = [];
}

// 获取会员贡献率
try {
    $member_sql = "
        SELECT 
            rk.period,
            rk.member_ratio,
            rk.new_member_count
        FROM 
            rpt_kpi rk
    ";

    $member_where = [];
    $member_params = [];

    if ($filter_store_id > 0) {
        $member_where[] = "rk.store_id = ?";
        $member_params[] = $filter_store_id;
    }

    if ($filter_year > 0) {
        $member_where[] = "rk.period LIKE ?";
        $member_params[] = $filter_year . '%';
    }

    if (!empty($member_where)) {
        $member_sql .= " WHERE " . implode(' AND ', $member_where);
    }

    $member_sql .= " ORDER BY rk.period ASC";

    $stmt = $pdo->prepare($member_sql);
    $stmt->execute($member_params);
    $member_contribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员贡献数据失败：' . $e->getMessage();
    $member_contribution = [];
}

// 获取年度KPI完成进度
try {
    // 假设有年度KPI目标表或字段，这里模拟一些目标值
    $annual_goals = [
        'revenue_goal' => 1000000, // 100万营业额目标
        'profit_goal' => 600000,   // 60万利润目标
        'orders_goal' => 30000,    // 3万单订单目标
        'members_goal' => 500      // 500名新会员目标
    ];

    // 计算年度至今的实际KPI数据
    $ytd_sql = "
        SELECT 
            SUM(rk.order_count) AS ytd_orders,
            SUM(rk.revenue) AS ytd_revenue,
            SUM(rk.gross_profit) AS ytd_profit,
            SUM(rk.new_member_count) AS ytd_new_members
        FROM 
            rpt_kpi rk
    ";

    $ytd_where = [];
    $ytd_params = [];

    if ($filter_year > 0) {
        $ytd_where[] = "rk.period LIKE ?";
        $ytd_params[] = $filter_year . '%';
    }

    if ($filter_store_id > 0) {
        $ytd_where[] = "rk.store_id = ?";
        $ytd_params[] = $filter_store_id;
    }

    if (!empty($ytd_where)) {
        $ytd_sql .= " WHERE " . implode(' AND ', $ytd_where);
    }

    $stmt = $pdo->prepare($ytd_sql);
    $stmt->execute($ytd_params);
    $ytd_kpi = $stmt->fetch();

    // 计算完成进度
    $progress = [
        'revenue_progress' => ($ytd_kpi['ytd_revenue'] / $annual_goals['revenue_goal']) * 100,
        'profit_progress' => ($ytd_kpi['ytd_profit'] / $annual_goals['profit_goal']) * 100,
        'orders_progress' => ($ytd_kpi['ytd_orders'] / $annual_goals['orders_goal']) * 100,
        'members_progress' => ($ytd_kpi['ytd_new_members'] / $annual_goals['members_goal']) * 100
    ];
} catch (PDOException $e) {
    $error = '获取年度KPI进度数据失败：' . $e->getMessage();
    $ytd_kpi = [
        'ytd_orders' => 0,
        'ytd_revenue' => 0,
        'ytd_profit' => 0,
        'ytd_new_members' => 0
    ];
    $progress = [
        'revenue_progress' => 0,
        'profit_progress' => 0,
        'orders_progress' => 0,
        'members_progress' => 0
    ];
}

// 辅助函数：获取比较类型名称
function getCompareTypeName($type)
{
    switch ($type) {
        case 1:
            return '同比';
        case 2:
            return '环比';
        default:
            return '无比较';
    }
}

// 辅助函数：格式化变化率显示
function formatChangeRate($rate, $isPercentagePoint = false)
{
    if ($rate > 0) {
        return '<span style="color: #2ecc71;">+' . number_format($rate, 2) . ($isPercentagePoint ? '百分点' : '%') . '</span>';
    } elseif ($rate < 0) {
        return '<span style="color: #e74c3c;">' . number_format($rate, 2) . ($isPercentagePoint ? '百分点' : '%') . '</span>';
    } else {
        return '<span>0' . ($isPercentagePoint ? '百分点' : '%') . '</span>';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>运营KPI统计</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 运营KPI统计
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 更新KPI数据表单 -->
            <div class="form-container">
                <h3>更新KPI数据</h3>
                <form method="post" action="">
                    <div class="form-row">
                        <div class="filter-item">
                            <label for="update_store_id">门店：</label>
                            <select id="update_store_id" name="update_store_id">
                                <option value="0">所有门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_year">年份：</label>
                            <select id="update_year" name="update_year">
                                <?php
                                $current_year = date('Y');
                                for ($y = $current_year; $y >= 2020; $y--):
                                ?>
                                    <option value="<?php echo $y; ?>"><?php echo $y; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_month">月份：</label>
                            <select id="update_month" name="update_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo (intval(date('n')) == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" name="update_kpi" value="1" class="btn btn-success">更新KPI数据</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="year">年份：</label>
                            <select id="year" name="year">
                                <option value="0" <?php echo ($filter_year == 0) ? 'selected' : ''; ?>>全部年份</option>
                                <?php foreach ($available_years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo ($filter_year == $year) ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_month">开始月份：</label>
                            <select id="start_month" name="start_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo ($filter_start_month == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="end_month">结束月份：</label>
                            <select id="end_month" name="end_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo ($filter_end_month == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="compare">比较方式：</label>
                            <select id="compare" name="compare">
                                <option value="0" <?php echo ($filter_compare == 0) ? 'selected' : ''; ?>>不比较</option>
                                <option value="1" <?php echo ($filter_compare == 1) ? 'selected' : ''; ?>>同比(去年同期)</option>
                                <option value="2" <?php echo ($filter_compare == 2) ? 'selected' : ''; ?>>环比(上月)</option>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">查询</button>
                            <a href="kpi.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 最新营业数据卡片 -->
            <div class="info-box">
                <h3>最近30天营业数据</h3>
                <ul>
                    <li>订单总数：<?php echo number_format($recent_data['recent_orders']); ?> 单</li>
                    <li>营业额：￥<?php echo number_format($recent_data['recent_revenue'], 2); ?></li>
                    <li>消费会员数：<?php echo number_format($recent_data['recent_members']); ?> 人</li>
                    <li>日均订单：<?php echo number_format($recent_data['recent_orders'] / 30, 1); ?> 单</li>
                </ul>
            </div>

            <!-- KPI统计摘要 -->
            <div class="info-box">
                <h3>KPI统计摘要（<?php echo $filter_year == 0 ? '全部年份' : $filter_year . '年'; ?> <?php echo $filter_start_month; ?>月至<?php echo $filter_end_month; ?>月 - <?php echo getCompareTypeName($filter_compare); ?>）</h3>
                <ul>
                    <li>总订单数：<?php echo number_format($kpi_summary['total_order_count']); ?> 单
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['order_count']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>总客流量：<?php echo number_format($kpi_summary['total_customer_count']); ?> 人次
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['customer_count']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>总营业额：￥<?php echo number_format($kpi_summary['total_revenue'], 2); ?>
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['revenue']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>平均营收增长率：<?php echo number_format($kpi_summary['avg_revenue_growth'], 2); ?>%
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['revenue_growth'], true); ?>]
                        <?php endif; ?>
                    </li>
                    <li>总毛利润：￥<?php echo number_format($kpi_summary['total_gross_profit'], 2); ?>
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['gross_profit']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>平均毛利率：<?php echo number_format($kpi_summary['avg_gross_profit_rate'], 2); ?>%
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['gross_profit_rate'], true); ?>]
                        <?php endif; ?>
                    </li>
                    <li>新增会员数：<?php echo number_format($kpi_summary['total_new_member_count']); ?> 人
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['new_member_count']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>会员消费总额：￥<?php echo number_format($kpi_summary['total_member_amount'], 2); ?>
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['member_amount']); ?>]
                        <?php endif; ?>
                    </li>
                    <li>平均会员消费占比：<?php echo number_format($kpi_summary['avg_member_ratio'], 2); ?>%
                        <?php if (!empty($compare_data)): ?>
                            [<?php echo formatChangeRate($change_rate['member_ratio'], true); ?>]
                        <?php endif; ?>
                    </li>
                </ul>
            </div>

            <!-- 年度KPI完成进度 -->
            <div class="info-box">
                <h3><?php echo $filter_year == 0 ? '全部年份' : $filter_year . '年'; ?>KPI完成进度</h3>
                <ul>
                    <li>营业额：￥<?php echo number_format($ytd_kpi['ytd_revenue'], 2); ?> / ￥<?php echo number_format($annual_goals['revenue_goal'], 2); ?> [<?php echo number_format($progress['revenue_progress'], 1); ?>%]</li>
                    <li>毛利润：￥<?php echo number_format($ytd_kpi['ytd_profit'], 2); ?> / ￥<?php echo number_format($annual_goals['profit_goal'], 2); ?> [<?php echo number_format($progress['profit_progress'], 1); ?>%]</li>
                    <li>订单数：<?php echo number_format($ytd_kpi['ytd_orders']); ?> / <?php echo number_format($annual_goals['orders_goal']); ?> [<?php echo number_format($progress['orders_progress'], 1); ?>%]</li>
                    <li>新会员：<?php echo number_format($ytd_kpi['ytd_new_members']); ?> / <?php echo number_format($annual_goals['members_goal']); ?> [<?php echo number_format($progress['members_progress'], 1); ?>%]</li>
                </ul>
            </div>

            <!-- 月度KPI数据表格 -->
            <div class="table-container">
                <h3>月度KPI数据列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>周期</th>
                            <th>门店</th>
                            <th>订单数</th>
                            <th>客流量</th>
                            <th>营业额</th>
                            <th>营收增长率</th>
                            <th>毛利润</th>
                            <th>毛利率</th>
                            <th>新增会员</th>
                            <th>会员消费额</th>
                            <th>会员消费占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($kpi_data)): ?>
                            <tr>
                                <td colspan="11" class="text-center">暂无KPI数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($kpi_data as $item): ?>
                                <tr>
                                    <td><?php echo $item['period']; ?></td>
                                    <td><?php echo htmlspecialchars($item['store_name']); ?></td>
                                    <td><?php echo number_format($item['order_count']); ?></td>
                                    <td><?php echo number_format($item['customer_count']); ?></td>
                                    <td>￥<?php echo number_format($item['revenue'], 2); ?></td>
                                    <td><?php echo number_format($item['revenue_growth'], 2); ?>%</td>
                                    <td>￥<?php echo number_format($item['gross_profit'], 2); ?></td>
                                    <td><?php echo number_format($item['gross_profit_rate'], 2); ?>%</td>
                                    <td><?php echo number_format($item['new_member_count']); ?></td>
                                    <td>￥<?php echo number_format($item['member_amount'], 2); ?></td>
                                    <td><?php echo number_format($item['member_ratio'], 2); ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 门店排名 -->
            <div class="table-container">
                <h3><?php echo $filter_year == 0 ? '全部年份' : $filter_year . '年'; ?>年度门店业绩排名</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>门店名称</th>
                            <th>订单总数</th>
                            <th>营业总额</th>
                            <th>毛利润</th>
                            <th>占总营收比例</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($store_rankings)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无门店排名数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $rank = 1;
                            $total_revenue_all_stores = 0;
                            foreach ($store_rankings as $store) {
                                $total_revenue_all_stores += $store['total_revenue'];
                            }

                            foreach ($store_rankings as $store):
                                $revenue_percentage = ($total_revenue_all_stores > 0) ? ($store['total_revenue'] / $total_revenue_all_stores) * 100 : 0;
                            ?>
                                <tr>
                                    <td><?php echo $rank++; ?></td>
                                    <td><?php echo htmlspecialchars($store['store_name']); ?></td>
                                    <td><?php echo number_format($store['total_orders']); ?></td>
                                    <td>￥<?php echo number_format($store['total_revenue'], 2); ?></td>
                                    <td>￥<?php echo number_format($store['total_profit'], 2); ?></td>
                                    <td><?php echo number_format($revenue_percentage, 2); ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 会员贡献分析 -->
            <div class="table-container">
                <h3><?php echo $filter_year == 0 ? '全部年份' : $filter_year . '年'; ?>年会员贡献分析</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>会员消费占比</th>
                            <th>新增会员数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($member_contribution)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无会员贡献数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($member_contribution as $item): ?>
                                <tr>
                                    <td><?php echo $item['period']; ?></td>
                                    <td><?php echo number_format($item['member_ratio'], 2); ?>%</td>
                                    <td><?php echo number_format($item['new_member_count']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <?php if (!empty($compare_data) && $filter_compare > 0): ?>
                <!-- 比较数据表格 -->
                <div class="table-container">
                    <h3><?php echo getCompareTypeName($filter_compare); ?>数据列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>周期</th>
                                <th>门店</th>
                                <th>订单数</th>
                                <th>客流量</th>
                                <th>营业额</th>
                                <th>营收增长率</th>
                                <th>毛利润</th>
                                <th>毛利率</th>
                                <th>新增会员</th>
                                <th>会员消费额</th>
                                <th>会员消费占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($compare_data)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无比较数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($compare_data as $item): ?>
                                    <tr>
                                        <td><?php echo $item['period']; ?></td>
                                        <td><?php echo htmlspecialchars($item['store_name']); ?></td>
                                        <td><?php echo number_format($item['order_count']); ?></td>
                                        <td><?php echo number_format($item['customer_count']); ?></td>
                                        <td>￥<?php echo number_format($item['revenue'], 2); ?></td>
                                        <td><?php echo number_format($item['revenue_growth'], 2); ?>%</td>
                                        <td>￥<?php echo number_format($item['gross_profit'], 2); ?></td>
                                        <td><?php echo number_format($item['gross_profit_rate'], 2); ?>%</td>
                                        <td><?php echo number_format($item['new_member_count']); ?></td>
                                        <td>￥<?php echo number_format($item['member_amount'], 2); ?></td>
                                        <td><?php echo number_format($item['member_ratio'], 2); ?>%</td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>