<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('statistics.sales');

// 记录访问日志
record_log('访问销售数据分析页面');

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_category_id = isset($_GET['category_id']) ? intval($_GET['category_id']) : 0;
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : ''; // 默认显示全部
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : ''; // 默认显示全部
$filter_sort = isset($_GET['sort']) ? trim($_GET['sort']) : 'quantity'; // 默认按销量排序
$filter_limit = isset($_GET['limit']) ? intval($_GET['limit']) : 10; // 默认显示前10名

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有产品分类，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, name AS category_name FROM product_category ORDER BY id");
    $categories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品分类失败：' . $e->getMessage();
    $categories = [];
}

// 处理销售数据更新请求
if (isset($_POST['update_sales'])) {
    $update_store_id = isset($_POST['update_store_id']) ? intval($_POST['update_store_id']) : 0;
    $update_year = isset($_POST['update_year']) ? intval($_POST['update_year']) : date('Y');
    $update_month = isset($_POST['update_month']) ? intval($_POST['update_month']) : date('n');

    try {
        // 设置统计周期
        $period = $update_year . '-' . str_pad($update_month, 2, '0', STR_PAD_LEFT);
        $start_date = $period . '-01';
        $end_date = date('Y-m-t', strtotime($start_date));

        // 准备查询条件
        $where_store = $update_store_id > 0 ? "AND o.store_id = " . $update_store_id : "";

        // 获取销售数据
        $sales_sql = "
            SELECT 
                o.store_id,
                oi.product_id,
                p.name AS product_name,
                pc.name AS category,
                COUNT(oi.id) AS sale_count,
                SUM(oi.quantity) AS total_quantity,
                SUM(oi.price * oi.quantity) AS sale_amount
            FROM 
                order_item oi
                JOIN order_main o ON oi.order_id = o.id
                JOIN product_items p ON oi.product_id = p.id
                JOIN product_category pc ON p.category = pc.id
            WHERE 
                o.create_time BETWEEN ? AND ?
                AND o.status IN (3, 4)
                $where_store
            GROUP BY 
                o.store_id, oi.product_id
            ORDER BY 
                sale_amount DESC
        ";

        $stmt = $pdo->prepare($sales_sql);
        $stmt->execute([
            $start_date . ' 00:00:00',
            $end_date . ' 23:59:59'
        ]);

        $sales_data = $stmt->fetchAll();

        $updated_count = 0;
        $store_ranking = [];

        // 整理每个门店的产品销售数据，用于计算排名
        foreach ($sales_data as $item) {
            if (!isset($store_ranking[$item['store_id']])) {
                $store_ranking[$item['store_id']] = [];
            }
            $store_ranking[$item['store_id']][] = [
                'product_id' => $item['product_id'],
                'sale_amount' => $item['sale_amount']
            ];
        }

        // 计算每个门店内产品的排名
        foreach ($store_ranking as $store_id => $products) {
            usort($products, function ($a, $b) {
                return $b['sale_amount'] <=> $a['sale_amount'];
            });

            foreach ($products as $rank => $product) {
                $store_ranking[$store_id][$rank]['rank'] = $rank + 1;
            }
        }

        // 更新或插入销售数据
        foreach ($sales_data as $item) {
            // 查找该产品在本门店的排名
            $rank = 0;
            foreach ($store_ranking[$item['store_id']] as $ranked_product) {
                if ($ranked_product['product_id'] == $item['product_id']) {
                    $rank = $ranked_product['rank'];
                    break;
                }
            }

            // 检查是否已存在该产品该周期的销售记录
            $check_sql = "
                SELECT id FROM rpt_sales 
                WHERE store_id = ? AND product_id = ? AND period = ?
            ";
            $check_stmt = $pdo->prepare($check_sql);
            $check_stmt->execute([$item['store_id'], $item['product_id'], $period]);
            $exists = $check_stmt->fetch();

            if ($exists) {
                // 更新现有记录
                $update_sql = "
                    UPDATE rpt_sales SET
                        product_name = ?,
                        category = ?,
                        sale_count = ?,
                        sale_amount = ?,
                        `rank` = ?
                    WHERE id = ?
                ";
                $update_stmt = $pdo->prepare($update_sql);
                $update_stmt->execute([
                    $item['product_name'],
                    $item['category'],
                    $item['total_quantity'],
                    $item['sale_amount'],
                    $rank,
                    $exists['id']
                ]);
            } else {
                // 添加新记录
                $insert_sql = "
                    INSERT INTO rpt_sales (
                        store_id, product_id, product_name, category, period,
                        sale_count, sale_amount, `rank`, create_time
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW())
                ";
                $insert_stmt = $pdo->prepare($insert_sql);
                $insert_stmt->execute([
                    $item['store_id'],
                    $item['product_id'],
                    $item['product_name'],
                    $item['category'],
                    $period,
                    $item['total_quantity'],
                    $item['sale_amount'],
                    $rank
                ]);
            }

            $updated_count++;
        }

        $success = "成功更新{$updated_count}条销售数据";
        record_log("更新{$period}期间的销售统计数据");
    } catch (PDOException $e) {
        $error = '更新销售数据失败：' . $e->getMessage();
    }
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "o.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_category_id > 0) {
    $where[] = "p.category = ?";
    $params[] = $filter_category_id;
}

if (!empty($filter_start_date)) {
    $where[] = "o.create_time >= ?";
    $params[] = $filter_start_date . ' 00:00:00';
}

if (!empty($filter_end_date)) {
    $where[] = "o.create_time <= ?";
    $params[] = $filter_end_date . ' 23:59:59';
}

// 默认条件：只统计已完成的订单
$where[] = "o.status IN (3, 4)"; // 假设3=已完成，4=已取餐

// 获取畅销商品数据
try {
    $sql = "
        SELECT 
            p.id AS product_id,
            p.name AS product_name,
            pc.name AS category_name,
            s.store_name,
            SUM(oi.quantity) AS total_quantity,
            SUM(oi.price * oi.quantity) AS total_amount,
            COUNT(DISTINCT o.id) AS order_count
        FROM 
            order_item oi
            JOIN order_main o ON oi.order_id = o.id
            JOIN product_items p ON oi.product_id = p.id
            JOIN product_category pc ON p.category = pc.id
            JOIN store_info s ON o.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " 
        GROUP BY 
            p.id, s.id
        ORDER BY 
    ";

    // 排序方式
    if ($filter_sort == 'amount') {
        $sql .= " total_amount DESC";
    } else {
        $sql .= " total_quantity DESC";
    }

    // 直接将LIMIT值嵌入SQL中，而不是用参数绑定
    $sql .= " LIMIT " . intval($filter_limit);

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params); // 不需要将$filter_limit添加到$params数组
    $top_products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取畅销商品数据失败：' . $e->getMessage();
    $top_products = [];
}

// 获取各门店销售总计
$store_params = $params;
try {
    $sql = "
        SELECT 
            s.id AS store_id,
            s.store_name,
            SUM(o.total_amount) AS total_amount,
            COUNT(o.id) AS order_count,
            COUNT(DISTINCT o.member_id) AS customer_count
        FROM 
            order_main o
            JOIN store_info s ON o.store_id = s.id
    ";

    $where_store = $where; // 复制条件
    if (!empty($where_store)) {
        $sql .= " WHERE " . implode(' AND ', $where_store);
    }

    $sql .= " 
        GROUP BY 
            s.id
        ORDER BY 
            total_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($store_params);
    $store_sales = $stmt->fetchAll();

    // 计算所有门店的总销售额
    $total_sales_amount = 0;
    $total_order_count = 0;
    $total_customer_count = 0;

    foreach ($store_sales as $store) {
        $total_sales_amount += $store['total_amount'];
        $total_order_count += $store['order_count'];
        $total_customer_count += $store['customer_count'];
    }
} catch (PDOException $e) {
    $error = '获取门店销售数据失败：' . $e->getMessage();
    $store_sales = [];
    $total_sales_amount = 0;
    $total_order_count = 0;
    $total_customer_count = 0;
}

// 获取各分类销售数据
$category_params = $params;
try {
    $sql = "
        SELECT 
            pc.id AS category_id,
            pc.name AS category_name,
            SUM(oi.quantity) AS total_quantity,
            SUM(oi.price * oi.quantity) AS total_amount,
            COUNT(DISTINCT o.id) AS order_count
        FROM 
            order_item oi
            JOIN order_main o ON oi.order_id = o.id
            JOIN product_items p ON oi.product_id = p.id
            JOIN product_category pc ON p.category = pc.id
    ";

    $where_category = $where; // 复制条件
    if (!empty($where_category)) {
        $sql .= " WHERE " . implode(' AND ', $where_category);
    }

    $sql .= " 
        GROUP BY 
            pc.id
        ORDER BY 
            total_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($category_params);
    $category_sales = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取分类销售数据失败：' . $e->getMessage();
    $category_sales = [];
}

// 销售趋势分析（按日期统计）
$trend_params = $params;
try {
    $trend_sql = "
        SELECT 
            DATE(o.create_time) AS sale_date,
            SUM(o.total_amount) AS daily_amount,
            COUNT(o.id) AS daily_orders
        FROM 
            order_main o
    ";

    $where_trend = $where; // 复制条件
    if (!empty($where_trend)) {
        $trend_sql .= " WHERE " . implode(' AND ', $where_trend);
    }

    $trend_sql .= " 
        GROUP BY 
            DATE(o.create_time)
        ORDER BY 
            sale_date
    ";

    $stmt = $pdo->prepare($trend_sql);
    $stmt->execute($trend_params);
    $sales_trend = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售趋势数据失败：' . $e->getMessage();
    $sales_trend = [];
}

// 简单的销量预测（基于过去30天或所选日期范围的平均销量）
$predictions = [];
if (!empty($top_products)) {
    foreach ($top_products as $product) {
        // 如果没有选择日期范围，默认使用30天作为基准
        if (empty($filter_start_date) || empty($filter_end_date)) {
            $days = 30;
        } else {
            $days = (strtotime($filter_end_date) - strtotime($filter_start_date)) / (60 * 60 * 24) + 1;
        }
        $daily_avg = $product['total_quantity'] / $days;

        // 预测未来7天的销量
        $predictions[$product['product_id']] = [
            'product_name' => $product['product_name'],
            'daily_avg' => round($daily_avg, 2),
            'weekly_forecast' => round($daily_avg * 7, 0),
            'monthly_forecast' => round($daily_avg * 30, 0)
        ];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 销售数据分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 更新销售数据表单 -->
            <div class="form-container">
                <h3>更新销售数据</h3>
                <form method="post" action="">
                    <div class="form-row">
                        <div class="filter-item">
                            <label for="update_store_id">门店：</label>
                            <select id="update_store_id" name="update_store_id">
                                <option value="0">所有门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>">
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_year">年份：</label>
                            <select id="update_year" name="update_year">
                                <?php
                                $current_year = date('Y');
                                for ($y = $current_year; $y >= 2020; $y--):
                                ?>
                                    <option value="<?php echo $y; ?>"><?php echo $y; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="update_month">月份：</label>
                            <select id="update_month" name="update_month">
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo (intval(date('n')) == $m) ? 'selected' : ''; ?>>
                                        <?php echo $m; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" name="update_sales" value="1" class="btn btn-success">更新销售数据</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">门店：</label>
                            <select id="store_id" name="store_id">
                                <option value="0">全部门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="category_id">产品分类：</label>
                            <select id="category_id" name="category_id">
                                <option value="0">全部分类</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['id']; ?>" <?php echo ($filter_category_id == $category['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($category['category_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                        </div>
                    </div>

                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="sort">排序方式：</label>
                            <select id="sort" name="sort">
                                <option value="quantity" <?php echo ($filter_sort == 'quantity') ? 'selected' : ''; ?>>按销量排序</option>
                                <option value="amount" <?php echo ($filter_sort == 'amount') ? 'selected' : ''; ?>>按销售额排序</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="limit">显示数量：</label>
                            <select id="limit" name="limit">
                                <option value="10" <?php echo ($filter_limit == 10) ? 'selected' : ''; ?>>前10名</option>
                                <option value="20" <?php echo ($filter_limit == 20) ? 'selected' : ''; ?>>前20名</option>
                                <option value="50" <?php echo ($filter_limit == 50) ? 'selected' : ''; ?>>前50名</option>
                                <option value="100" <?php echo ($filter_limit == 100) ? 'selected' : ''; ?>>前100名</option>
                            </select>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">查询</button>
                            <a href="sales.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 统计摘要 -->
            <div class="info-box">
                <h3>销售统计摘要（<?php echo empty($filter_start_date) && empty($filter_end_date) ? '全部数据' : $filter_start_date . ' 至 ' . $filter_end_date; ?>）</h3>
                <ul>
                    <li>总销售额：￥<?php echo number_format($total_sales_amount, 2); ?></li>
                    <li>总订单数：<?php echo $total_order_count; ?></li>
                    <li>总客户数：<?php echo $total_customer_count; ?></li>
                    <li>平均客单价：￥<?php echo $total_customer_count > 0 ? number_format($total_sales_amount / $total_customer_count, 2) : '0.00'; ?></li>
                </ul>
            </div>

            <!-- 畅销商品列表 -->
            <div class="table-container">
                <h3>畅销商品排行（<?php echo $filter_sort == 'quantity' ? '按销量' : '按销售额'; ?>）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>商品名称</th>
                            <th>分类</th>
                            <th>门店</th>
                            <th>销售数量</th>
                            <th>销售金额</th>
                            <th>订单数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($top_products)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无销售数据</td>
                            </tr>
                        <?php else: ?>
                            <?php $rank = 1;
                            foreach ($top_products as $product): ?>
                                <tr>
                                    <td><?php echo $rank++; ?></td>
                                    <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                                    <td><?php echo htmlspecialchars($product['category_name']); ?></td>
                                    <td><?php echo htmlspecialchars($product['store_name']); ?></td>
                                    <td><?php echo $product['total_quantity']; ?></td>
                                    <td>￥<?php echo number_format($product['total_amount'], 2); ?></td>
                                    <td><?php echo $product['order_count']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 门店销售排行 -->
            <div class="table-container">
                <h3>门店销售排行</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>门店名称</th>
                            <th>销售金额</th>
                            <th>订单数量</th>
                            <th>客户数量</th>
                            <th>客单价</th>
                            <th>占总销售比例</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($store_sales)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无门店销售数据</td>
                            </tr>
                        <?php else: ?>
                            <?php $rank = 1;
                            foreach ($store_sales as $store): ?>
                                <tr>
                                    <td><?php echo $rank++; ?></td>
                                    <td><?php echo htmlspecialchars($store['store_name']); ?></td>
                                    <td>￥<?php echo number_format($store['total_amount'], 2); ?></td>
                                    <td><?php echo $store['order_count']; ?></td>
                                    <td><?php echo $store['customer_count']; ?></td>
                                    <td>￥<?php echo $store['customer_count'] > 0 ? number_format($store['total_amount'] / $store['customer_count'], 2) : '0.00'; ?></td>
                                    <td><?php echo $total_sales_amount > 0 ? number_format(($store['total_amount'] / $total_sales_amount) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分类销售统计 -->
            <div class="table-container">
                <h3>产品分类销售统计</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>分类名称</th>
                            <th>销售数量</th>
                            <th>销售金额</th>
                            <th>订单数量</th>
                            <th>占总销售比例</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($category_sales)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无分类销售数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($category_sales as $category): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($category['category_name']); ?></td>
                                    <td><?php echo $category['total_quantity']; ?></td>
                                    <td>￥<?php echo number_format($category['total_amount'], 2); ?></td>
                                    <td><?php echo $category['order_count']; ?></td>
                                    <td><?php echo $total_sales_amount > 0 ? number_format(($category['total_amount'] / $total_sales_amount) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 销量预测分析 -->
            <div class="table-container">
                <h3>销量预测分析</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>商品名称</th>
                            <th>日均销量</th>
                            <th>7天预测销量</th>
                            <th>30天预测销量</th>
                            <th>建议采购量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($predictions)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无销量预测数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($predictions as $prediction): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($prediction['product_name']); ?></td>
                                    <td><?php echo $prediction['daily_avg']; ?></td>
                                    <td><?php echo $prediction['weekly_forecast']; ?></td>
                                    <td><?php echo $prediction['monthly_forecast']; ?></td>
                                    <td><?php echo ceil($prediction['weekly_forecast'] * 1.2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 销售趋势分析 -->
            <div class="table-container">
                <h3>销售趋势分析</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <th>销售金额</th>
                            <th>订单数量</th>
                            <th>客单价</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($sales_trend)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无销售趋势数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($sales_trend as $trend): ?>
                                <tr>
                                    <td><?php echo $trend['sale_date']; ?></td>
                                    <td>￥<?php echo number_format($trend['daily_amount'], 2); ?></td>
                                    <td><?php echo $trend['daily_orders']; ?></td>
                                    <td>￥<?php echo $trend['daily_orders'] > 0 ? number_format($trend['daily_amount'] / $trend['daily_orders'], 2) : '0.00'; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>